# name: MVE vmlsdav instructions
# as: -march=armv8.1-m.main+mve.fp
# objdump: -dr --prefix-addresses --show-raw-insn -marmv8.1-m.main

.*: +file format .*arm.*

Disassembly of section .text:
[^>]*> fef0 0e01 	vmlsdav.s8	r0, q0, q0
[^>]*> fef0 0e21 	vmlsdava.s8	r0, q0, q0
[^>]*> fef0 1e01 	vmlsdavx.s8	r0, q0, q0
[^>]*> fef0 1e21 	vmlsdavax.s8	r0, q0, q0
[^>]*> fef0 0e03 	vmlsdav.s8	r0, q0, q1
[^>]*> fef0 0e23 	vmlsdava.s8	r0, q0, q1
[^>]*> fef0 1e03 	vmlsdavx.s8	r0, q0, q1
[^>]*> fef0 1e23 	vmlsdavax.s8	r0, q0, q1
[^>]*> fef0 0e05 	vmlsdav.s8	r0, q0, q2
[^>]*> fef0 0e25 	vmlsdava.s8	r0, q0, q2
[^>]*> fef0 1e05 	vmlsdavx.s8	r0, q0, q2
[^>]*> fef0 1e25 	vmlsdavax.s8	r0, q0, q2
[^>]*> fef0 0e09 	vmlsdav.s8	r0, q0, q4
[^>]*> fef0 0e29 	vmlsdava.s8	r0, q0, q4
[^>]*> fef0 1e09 	vmlsdavx.s8	r0, q0, q4
[^>]*> fef0 1e29 	vmlsdavax.s8	r0, q0, q4
[^>]*> fef0 0e0f 	vmlsdav.s8	r0, q0, q7
[^>]*> fef0 0e2f 	vmlsdava.s8	r0, q0, q7
[^>]*> fef0 1e0f 	vmlsdavx.s8	r0, q0, q7
[^>]*> fef0 1e2f 	vmlsdavax.s8	r0, q0, q7
[^>]*> fef2 0e01 	vmlsdav.s8	r0, q1, q0
[^>]*> fef2 0e21 	vmlsdava.s8	r0, q1, q0
[^>]*> fef2 1e01 	vmlsdavx.s8	r0, q1, q0
[^>]*> fef2 1e21 	vmlsdavax.s8	r0, q1, q0
[^>]*> fef2 0e03 	vmlsdav.s8	r0, q1, q1
[^>]*> fef2 0e23 	vmlsdava.s8	r0, q1, q1
[^>]*> fef2 1e03 	vmlsdavx.s8	r0, q1, q1
[^>]*> fef2 1e23 	vmlsdavax.s8	r0, q1, q1
[^>]*> fef2 0e05 	vmlsdav.s8	r0, q1, q2
[^>]*> fef2 0e25 	vmlsdava.s8	r0, q1, q2
[^>]*> fef2 1e05 	vmlsdavx.s8	r0, q1, q2
[^>]*> fef2 1e25 	vmlsdavax.s8	r0, q1, q2
[^>]*> fef2 0e09 	vmlsdav.s8	r0, q1, q4
[^>]*> fef2 0e29 	vmlsdava.s8	r0, q1, q4
[^>]*> fef2 1e09 	vmlsdavx.s8	r0, q1, q4
[^>]*> fef2 1e29 	vmlsdavax.s8	r0, q1, q4
[^>]*> fef2 0e0f 	vmlsdav.s8	r0, q1, q7
[^>]*> fef2 0e2f 	vmlsdava.s8	r0, q1, q7
[^>]*> fef2 1e0f 	vmlsdavx.s8	r0, q1, q7
[^>]*> fef2 1e2f 	vmlsdavax.s8	r0, q1, q7
[^>]*> fef4 0e01 	vmlsdav.s8	r0, q2, q0
[^>]*> fef4 0e21 	vmlsdava.s8	r0, q2, q0
[^>]*> fef4 1e01 	vmlsdavx.s8	r0, q2, q0
[^>]*> fef4 1e21 	vmlsdavax.s8	r0, q2, q0
[^>]*> fef4 0e03 	vmlsdav.s8	r0, q2, q1
[^>]*> fef4 0e23 	vmlsdava.s8	r0, q2, q1
[^>]*> fef4 1e03 	vmlsdavx.s8	r0, q2, q1
[^>]*> fef4 1e23 	vmlsdavax.s8	r0, q2, q1
[^>]*> fef4 0e05 	vmlsdav.s8	r0, q2, q2
[^>]*> fef4 0e25 	vmlsdava.s8	r0, q2, q2
[^>]*> fef4 1e05 	vmlsdavx.s8	r0, q2, q2
[^>]*> fef4 1e25 	vmlsdavax.s8	r0, q2, q2
[^>]*> fef4 0e09 	vmlsdav.s8	r0, q2, q4
[^>]*> fef4 0e29 	vmlsdava.s8	r0, q2, q4
[^>]*> fef4 1e09 	vmlsdavx.s8	r0, q2, q4
[^>]*> fef4 1e29 	vmlsdavax.s8	r0, q2, q4
[^>]*> fef4 0e0f 	vmlsdav.s8	r0, q2, q7
[^>]*> fef4 0e2f 	vmlsdava.s8	r0, q2, q7
[^>]*> fef4 1e0f 	vmlsdavx.s8	r0, q2, q7
[^>]*> fef4 1e2f 	vmlsdavax.s8	r0, q2, q7
[^>]*> fef8 0e01 	vmlsdav.s8	r0, q4, q0
[^>]*> fef8 0e21 	vmlsdava.s8	r0, q4, q0
[^>]*> fef8 1e01 	vmlsdavx.s8	r0, q4, q0
[^>]*> fef8 1e21 	vmlsdavax.s8	r0, q4, q0
[^>]*> fef8 0e03 	vmlsdav.s8	r0, q4, q1
[^>]*> fef8 0e23 	vmlsdava.s8	r0, q4, q1
[^>]*> fef8 1e03 	vmlsdavx.s8	r0, q4, q1
[^>]*> fef8 1e23 	vmlsdavax.s8	r0, q4, q1
[^>]*> fef8 0e05 	vmlsdav.s8	r0, q4, q2
[^>]*> fef8 0e25 	vmlsdava.s8	r0, q4, q2
[^>]*> fef8 1e05 	vmlsdavx.s8	r0, q4, q2
[^>]*> fef8 1e25 	vmlsdavax.s8	r0, q4, q2
[^>]*> fef8 0e09 	vmlsdav.s8	r0, q4, q4
[^>]*> fef8 0e29 	vmlsdava.s8	r0, q4, q4
[^>]*> fef8 1e09 	vmlsdavx.s8	r0, q4, q4
[^>]*> fef8 1e29 	vmlsdavax.s8	r0, q4, q4
[^>]*> fef8 0e0f 	vmlsdav.s8	r0, q4, q7
[^>]*> fef8 0e2f 	vmlsdava.s8	r0, q4, q7
[^>]*> fef8 1e0f 	vmlsdavx.s8	r0, q4, q7
[^>]*> fef8 1e2f 	vmlsdavax.s8	r0, q4, q7
[^>]*> fefe 0e01 	vmlsdav.s8	r0, q7, q0
[^>]*> fefe 0e21 	vmlsdava.s8	r0, q7, q0
[^>]*> fefe 1e01 	vmlsdavx.s8	r0, q7, q0
[^>]*> fefe 1e21 	vmlsdavax.s8	r0, q7, q0
[^>]*> fefe 0e03 	vmlsdav.s8	r0, q7, q1
[^>]*> fefe 0e23 	vmlsdava.s8	r0, q7, q1
[^>]*> fefe 1e03 	vmlsdavx.s8	r0, q7, q1
[^>]*> fefe 1e23 	vmlsdavax.s8	r0, q7, q1
[^>]*> fefe 0e05 	vmlsdav.s8	r0, q7, q2
[^>]*> fefe 0e25 	vmlsdava.s8	r0, q7, q2
[^>]*> fefe 1e05 	vmlsdavx.s8	r0, q7, q2
[^>]*> fefe 1e25 	vmlsdavax.s8	r0, q7, q2
[^>]*> fefe 0e09 	vmlsdav.s8	r0, q7, q4
[^>]*> fefe 0e29 	vmlsdava.s8	r0, q7, q4
[^>]*> fefe 1e09 	vmlsdavx.s8	r0, q7, q4
[^>]*> fefe 1e29 	vmlsdavax.s8	r0, q7, q4
[^>]*> fefe 0e0f 	vmlsdav.s8	r0, q7, q7
[^>]*> fefe 0e2f 	vmlsdava.s8	r0, q7, q7
[^>]*> fefe 1e0f 	vmlsdavx.s8	r0, q7, q7
[^>]*> fefe 1e2f 	vmlsdavax.s8	r0, q7, q7
[^>]*> fef0 2e01 	vmlsdav.s8	r2, q0, q0
[^>]*> fef0 2e21 	vmlsdava.s8	r2, q0, q0
[^>]*> fef0 3e01 	vmlsdavx.s8	r2, q0, q0
[^>]*> fef0 3e21 	vmlsdavax.s8	r2, q0, q0
[^>]*> fef0 2e03 	vmlsdav.s8	r2, q0, q1
[^>]*> fef0 2e23 	vmlsdava.s8	r2, q0, q1
[^>]*> fef0 3e03 	vmlsdavx.s8	r2, q0, q1
[^>]*> fef0 3e23 	vmlsdavax.s8	r2, q0, q1
[^>]*> fef0 2e05 	vmlsdav.s8	r2, q0, q2
[^>]*> fef0 2e25 	vmlsdava.s8	r2, q0, q2
[^>]*> fef0 3e05 	vmlsdavx.s8	r2, q0, q2
[^>]*> fef0 3e25 	vmlsdavax.s8	r2, q0, q2
[^>]*> fef0 2e09 	vmlsdav.s8	r2, q0, q4
[^>]*> fef0 2e29 	vmlsdava.s8	r2, q0, q4
[^>]*> fef0 3e09 	vmlsdavx.s8	r2, q0, q4
[^>]*> fef0 3e29 	vmlsdavax.s8	r2, q0, q4
[^>]*> fef0 2e0f 	vmlsdav.s8	r2, q0, q7
[^>]*> fef0 2e2f 	vmlsdava.s8	r2, q0, q7
[^>]*> fef0 3e0f 	vmlsdavx.s8	r2, q0, q7
[^>]*> fef0 3e2f 	vmlsdavax.s8	r2, q0, q7
[^>]*> fef2 2e01 	vmlsdav.s8	r2, q1, q0
[^>]*> fef2 2e21 	vmlsdava.s8	r2, q1, q0
[^>]*> fef2 3e01 	vmlsdavx.s8	r2, q1, q0
[^>]*> fef2 3e21 	vmlsdavax.s8	r2, q1, q0
[^>]*> fef2 2e03 	vmlsdav.s8	r2, q1, q1
[^>]*> fef2 2e23 	vmlsdava.s8	r2, q1, q1
[^>]*> fef2 3e03 	vmlsdavx.s8	r2, q1, q1
[^>]*> fef2 3e23 	vmlsdavax.s8	r2, q1, q1
[^>]*> fef2 2e05 	vmlsdav.s8	r2, q1, q2
[^>]*> fef2 2e25 	vmlsdava.s8	r2, q1, q2
[^>]*> fef2 3e05 	vmlsdavx.s8	r2, q1, q2
[^>]*> fef2 3e25 	vmlsdavax.s8	r2, q1, q2
[^>]*> fef2 2e09 	vmlsdav.s8	r2, q1, q4
[^>]*> fef2 2e29 	vmlsdava.s8	r2, q1, q4
[^>]*> fef2 3e09 	vmlsdavx.s8	r2, q1, q4
[^>]*> fef2 3e29 	vmlsdavax.s8	r2, q1, q4
[^>]*> fef2 2e0f 	vmlsdav.s8	r2, q1, q7
[^>]*> fef2 2e2f 	vmlsdava.s8	r2, q1, q7
[^>]*> fef2 3e0f 	vmlsdavx.s8	r2, q1, q7
[^>]*> fef2 3e2f 	vmlsdavax.s8	r2, q1, q7
[^>]*> fef4 2e01 	vmlsdav.s8	r2, q2, q0
[^>]*> fef4 2e21 	vmlsdava.s8	r2, q2, q0
[^>]*> fef4 3e01 	vmlsdavx.s8	r2, q2, q0
[^>]*> fef4 3e21 	vmlsdavax.s8	r2, q2, q0
[^>]*> fef4 2e03 	vmlsdav.s8	r2, q2, q1
[^>]*> fef4 2e23 	vmlsdava.s8	r2, q2, q1
[^>]*> fef4 3e03 	vmlsdavx.s8	r2, q2, q1
[^>]*> fef4 3e23 	vmlsdavax.s8	r2, q2, q1
[^>]*> fef4 2e05 	vmlsdav.s8	r2, q2, q2
[^>]*> fef4 2e25 	vmlsdava.s8	r2, q2, q2
[^>]*> fef4 3e05 	vmlsdavx.s8	r2, q2, q2
[^>]*> fef4 3e25 	vmlsdavax.s8	r2, q2, q2
[^>]*> fef4 2e09 	vmlsdav.s8	r2, q2, q4
[^>]*> fef4 2e29 	vmlsdava.s8	r2, q2, q4
[^>]*> fef4 3e09 	vmlsdavx.s8	r2, q2, q4
[^>]*> fef4 3e29 	vmlsdavax.s8	r2, q2, q4
[^>]*> fef4 2e0f 	vmlsdav.s8	r2, q2, q7
[^>]*> fef4 2e2f 	vmlsdava.s8	r2, q2, q7
[^>]*> fef4 3e0f 	vmlsdavx.s8	r2, q2, q7
[^>]*> fef4 3e2f 	vmlsdavax.s8	r2, q2, q7
[^>]*> fef8 2e01 	vmlsdav.s8	r2, q4, q0
[^>]*> fef8 2e21 	vmlsdava.s8	r2, q4, q0
[^>]*> fef8 3e01 	vmlsdavx.s8	r2, q4, q0
[^>]*> fef8 3e21 	vmlsdavax.s8	r2, q4, q0
[^>]*> fef8 2e03 	vmlsdav.s8	r2, q4, q1
[^>]*> fef8 2e23 	vmlsdava.s8	r2, q4, q1
[^>]*> fef8 3e03 	vmlsdavx.s8	r2, q4, q1
[^>]*> fef8 3e23 	vmlsdavax.s8	r2, q4, q1
[^>]*> fef8 2e05 	vmlsdav.s8	r2, q4, q2
[^>]*> fef8 2e25 	vmlsdava.s8	r2, q4, q2
[^>]*> fef8 3e05 	vmlsdavx.s8	r2, q4, q2
[^>]*> fef8 3e25 	vmlsdavax.s8	r2, q4, q2
[^>]*> fef8 2e09 	vmlsdav.s8	r2, q4, q4
[^>]*> fef8 2e29 	vmlsdava.s8	r2, q4, q4
[^>]*> fef8 3e09 	vmlsdavx.s8	r2, q4, q4
[^>]*> fef8 3e29 	vmlsdavax.s8	r2, q4, q4
[^>]*> fef8 2e0f 	vmlsdav.s8	r2, q4, q7
[^>]*> fef8 2e2f 	vmlsdava.s8	r2, q4, q7
[^>]*> fef8 3e0f 	vmlsdavx.s8	r2, q4, q7
[^>]*> fef8 3e2f 	vmlsdavax.s8	r2, q4, q7
[^>]*> fefe 2e01 	vmlsdav.s8	r2, q7, q0
[^>]*> fefe 2e21 	vmlsdava.s8	r2, q7, q0
[^>]*> fefe 3e01 	vmlsdavx.s8	r2, q7, q0
[^>]*> fefe 3e21 	vmlsdavax.s8	r2, q7, q0
[^>]*> fefe 2e03 	vmlsdav.s8	r2, q7, q1
[^>]*> fefe 2e23 	vmlsdava.s8	r2, q7, q1
[^>]*> fefe 3e03 	vmlsdavx.s8	r2, q7, q1
[^>]*> fefe 3e23 	vmlsdavax.s8	r2, q7, q1
[^>]*> fefe 2e05 	vmlsdav.s8	r2, q7, q2
[^>]*> fefe 2e25 	vmlsdava.s8	r2, q7, q2
[^>]*> fefe 3e05 	vmlsdavx.s8	r2, q7, q2
[^>]*> fefe 3e25 	vmlsdavax.s8	r2, q7, q2
[^>]*> fefe 2e09 	vmlsdav.s8	r2, q7, q4
[^>]*> fefe 2e29 	vmlsdava.s8	r2, q7, q4
[^>]*> fefe 3e09 	vmlsdavx.s8	r2, q7, q4
[^>]*> fefe 3e29 	vmlsdavax.s8	r2, q7, q4
[^>]*> fefe 2e0f 	vmlsdav.s8	r2, q7, q7
[^>]*> fefe 2e2f 	vmlsdava.s8	r2, q7, q7
[^>]*> fefe 3e0f 	vmlsdavx.s8	r2, q7, q7
[^>]*> fefe 3e2f 	vmlsdavax.s8	r2, q7, q7
[^>]*> fef0 4e01 	vmlsdav.s8	r4, q0, q0
[^>]*> fef0 4e21 	vmlsdava.s8	r4, q0, q0
[^>]*> fef0 5e01 	vmlsdavx.s8	r4, q0, q0
[^>]*> fef0 5e21 	vmlsdavax.s8	r4, q0, q0
[^>]*> fef0 4e03 	vmlsdav.s8	r4, q0, q1
[^>]*> fef0 4e23 	vmlsdava.s8	r4, q0, q1
[^>]*> fef0 5e03 	vmlsdavx.s8	r4, q0, q1
[^>]*> fef0 5e23 	vmlsdavax.s8	r4, q0, q1
[^>]*> fef0 4e05 	vmlsdav.s8	r4, q0, q2
[^>]*> fef0 4e25 	vmlsdava.s8	r4, q0, q2
[^>]*> fef0 5e05 	vmlsdavx.s8	r4, q0, q2
[^>]*> fef0 5e25 	vmlsdavax.s8	r4, q0, q2
[^>]*> fef0 4e09 	vmlsdav.s8	r4, q0, q4
[^>]*> fef0 4e29 	vmlsdava.s8	r4, q0, q4
[^>]*> fef0 5e09 	vmlsdavx.s8	r4, q0, q4
[^>]*> fef0 5e29 	vmlsdavax.s8	r4, q0, q4
[^>]*> fef0 4e0f 	vmlsdav.s8	r4, q0, q7
[^>]*> fef0 4e2f 	vmlsdava.s8	r4, q0, q7
[^>]*> fef0 5e0f 	vmlsdavx.s8	r4, q0, q7
[^>]*> fef0 5e2f 	vmlsdavax.s8	r4, q0, q7
[^>]*> fef2 4e01 	vmlsdav.s8	r4, q1, q0
[^>]*> fef2 4e21 	vmlsdava.s8	r4, q1, q0
[^>]*> fef2 5e01 	vmlsdavx.s8	r4, q1, q0
[^>]*> fef2 5e21 	vmlsdavax.s8	r4, q1, q0
[^>]*> fef2 4e03 	vmlsdav.s8	r4, q1, q1
[^>]*> fef2 4e23 	vmlsdava.s8	r4, q1, q1
[^>]*> fef2 5e03 	vmlsdavx.s8	r4, q1, q1
[^>]*> fef2 5e23 	vmlsdavax.s8	r4, q1, q1
[^>]*> fef2 4e05 	vmlsdav.s8	r4, q1, q2
[^>]*> fef2 4e25 	vmlsdava.s8	r4, q1, q2
[^>]*> fef2 5e05 	vmlsdavx.s8	r4, q1, q2
[^>]*> fef2 5e25 	vmlsdavax.s8	r4, q1, q2
[^>]*> fef2 4e09 	vmlsdav.s8	r4, q1, q4
[^>]*> fef2 4e29 	vmlsdava.s8	r4, q1, q4
[^>]*> fef2 5e09 	vmlsdavx.s8	r4, q1, q4
[^>]*> fef2 5e29 	vmlsdavax.s8	r4, q1, q4
[^>]*> fef2 4e0f 	vmlsdav.s8	r4, q1, q7
[^>]*> fef2 4e2f 	vmlsdava.s8	r4, q1, q7
[^>]*> fef2 5e0f 	vmlsdavx.s8	r4, q1, q7
[^>]*> fef2 5e2f 	vmlsdavax.s8	r4, q1, q7
[^>]*> fef4 4e01 	vmlsdav.s8	r4, q2, q0
[^>]*> fef4 4e21 	vmlsdava.s8	r4, q2, q0
[^>]*> fef4 5e01 	vmlsdavx.s8	r4, q2, q0
[^>]*> fef4 5e21 	vmlsdavax.s8	r4, q2, q0
[^>]*> fef4 4e03 	vmlsdav.s8	r4, q2, q1
[^>]*> fef4 4e23 	vmlsdava.s8	r4, q2, q1
[^>]*> fef4 5e03 	vmlsdavx.s8	r4, q2, q1
[^>]*> fef4 5e23 	vmlsdavax.s8	r4, q2, q1
[^>]*> fef4 4e05 	vmlsdav.s8	r4, q2, q2
[^>]*> fef4 4e25 	vmlsdava.s8	r4, q2, q2
[^>]*> fef4 5e05 	vmlsdavx.s8	r4, q2, q2
[^>]*> fef4 5e25 	vmlsdavax.s8	r4, q2, q2
[^>]*> fef4 4e09 	vmlsdav.s8	r4, q2, q4
[^>]*> fef4 4e29 	vmlsdava.s8	r4, q2, q4
[^>]*> fef4 5e09 	vmlsdavx.s8	r4, q2, q4
[^>]*> fef4 5e29 	vmlsdavax.s8	r4, q2, q4
[^>]*> fef4 4e0f 	vmlsdav.s8	r4, q2, q7
[^>]*> fef4 4e2f 	vmlsdava.s8	r4, q2, q7
[^>]*> fef4 5e0f 	vmlsdavx.s8	r4, q2, q7
[^>]*> fef4 5e2f 	vmlsdavax.s8	r4, q2, q7
[^>]*> fef8 4e01 	vmlsdav.s8	r4, q4, q0
[^>]*> fef8 4e21 	vmlsdava.s8	r4, q4, q0
[^>]*> fef8 5e01 	vmlsdavx.s8	r4, q4, q0
[^>]*> fef8 5e21 	vmlsdavax.s8	r4, q4, q0
[^>]*> fef8 4e03 	vmlsdav.s8	r4, q4, q1
[^>]*> fef8 4e23 	vmlsdava.s8	r4, q4, q1
[^>]*> fef8 5e03 	vmlsdavx.s8	r4, q4, q1
[^>]*> fef8 5e23 	vmlsdavax.s8	r4, q4, q1
[^>]*> fef8 4e05 	vmlsdav.s8	r4, q4, q2
[^>]*> fef8 4e25 	vmlsdava.s8	r4, q4, q2
[^>]*> fef8 5e05 	vmlsdavx.s8	r4, q4, q2
[^>]*> fef8 5e25 	vmlsdavax.s8	r4, q4, q2
[^>]*> fef8 4e09 	vmlsdav.s8	r4, q4, q4
[^>]*> fef8 4e29 	vmlsdava.s8	r4, q4, q4
[^>]*> fef8 5e09 	vmlsdavx.s8	r4, q4, q4
[^>]*> fef8 5e29 	vmlsdavax.s8	r4, q4, q4
[^>]*> fef8 4e0f 	vmlsdav.s8	r4, q4, q7
[^>]*> fef8 4e2f 	vmlsdava.s8	r4, q4, q7
[^>]*> fef8 5e0f 	vmlsdavx.s8	r4, q4, q7
[^>]*> fef8 5e2f 	vmlsdavax.s8	r4, q4, q7
[^>]*> fefe 4e01 	vmlsdav.s8	r4, q7, q0
[^>]*> fefe 4e21 	vmlsdava.s8	r4, q7, q0
[^>]*> fefe 5e01 	vmlsdavx.s8	r4, q7, q0
[^>]*> fefe 5e21 	vmlsdavax.s8	r4, q7, q0
[^>]*> fefe 4e03 	vmlsdav.s8	r4, q7, q1
[^>]*> fefe 4e23 	vmlsdava.s8	r4, q7, q1
[^>]*> fefe 5e03 	vmlsdavx.s8	r4, q7, q1
[^>]*> fefe 5e23 	vmlsdavax.s8	r4, q7, q1
[^>]*> fefe 4e05 	vmlsdav.s8	r4, q7, q2
[^>]*> fefe 4e25 	vmlsdava.s8	r4, q7, q2
[^>]*> fefe 5e05 	vmlsdavx.s8	r4, q7, q2
[^>]*> fefe 5e25 	vmlsdavax.s8	r4, q7, q2
[^>]*> fefe 4e09 	vmlsdav.s8	r4, q7, q4
[^>]*> fefe 4e29 	vmlsdava.s8	r4, q7, q4
[^>]*> fefe 5e09 	vmlsdavx.s8	r4, q7, q4
[^>]*> fefe 5e29 	vmlsdavax.s8	r4, q7, q4
[^>]*> fefe 4e0f 	vmlsdav.s8	r4, q7, q7
[^>]*> fefe 4e2f 	vmlsdava.s8	r4, q7, q7
[^>]*> fefe 5e0f 	vmlsdavx.s8	r4, q7, q7
[^>]*> fefe 5e2f 	vmlsdavax.s8	r4, q7, q7
[^>]*> fef0 8e01 	vmlsdav.s8	r8, q0, q0
[^>]*> fef0 8e21 	vmlsdava.s8	r8, q0, q0
[^>]*> fef0 9e01 	vmlsdavx.s8	r8, q0, q0
[^>]*> fef0 9e21 	vmlsdavax.s8	r8, q0, q0
[^>]*> fef0 8e03 	vmlsdav.s8	r8, q0, q1
[^>]*> fef0 8e23 	vmlsdava.s8	r8, q0, q1
[^>]*> fef0 9e03 	vmlsdavx.s8	r8, q0, q1
[^>]*> fef0 9e23 	vmlsdavax.s8	r8, q0, q1
[^>]*> fef0 8e05 	vmlsdav.s8	r8, q0, q2
[^>]*> fef0 8e25 	vmlsdava.s8	r8, q0, q2
[^>]*> fef0 9e05 	vmlsdavx.s8	r8, q0, q2
[^>]*> fef0 9e25 	vmlsdavax.s8	r8, q0, q2
[^>]*> fef0 8e09 	vmlsdav.s8	r8, q0, q4
[^>]*> fef0 8e29 	vmlsdava.s8	r8, q0, q4
[^>]*> fef0 9e09 	vmlsdavx.s8	r8, q0, q4
[^>]*> fef0 9e29 	vmlsdavax.s8	r8, q0, q4
[^>]*> fef0 8e0f 	vmlsdav.s8	r8, q0, q7
[^>]*> fef0 8e2f 	vmlsdava.s8	r8, q0, q7
[^>]*> fef0 9e0f 	vmlsdavx.s8	r8, q0, q7
[^>]*> fef0 9e2f 	vmlsdavax.s8	r8, q0, q7
[^>]*> fef2 8e01 	vmlsdav.s8	r8, q1, q0
[^>]*> fef2 8e21 	vmlsdava.s8	r8, q1, q0
[^>]*> fef2 9e01 	vmlsdavx.s8	r8, q1, q0
[^>]*> fef2 9e21 	vmlsdavax.s8	r8, q1, q0
[^>]*> fef2 8e03 	vmlsdav.s8	r8, q1, q1
[^>]*> fef2 8e23 	vmlsdava.s8	r8, q1, q1
[^>]*> fef2 9e03 	vmlsdavx.s8	r8, q1, q1
[^>]*> fef2 9e23 	vmlsdavax.s8	r8, q1, q1
[^>]*> fef2 8e05 	vmlsdav.s8	r8, q1, q2
[^>]*> fef2 8e25 	vmlsdava.s8	r8, q1, q2
[^>]*> fef2 9e05 	vmlsdavx.s8	r8, q1, q2
[^>]*> fef2 9e25 	vmlsdavax.s8	r8, q1, q2
[^>]*> fef2 8e09 	vmlsdav.s8	r8, q1, q4
[^>]*> fef2 8e29 	vmlsdava.s8	r8, q1, q4
[^>]*> fef2 9e09 	vmlsdavx.s8	r8, q1, q4
[^>]*> fef2 9e29 	vmlsdavax.s8	r8, q1, q4
[^>]*> fef2 8e0f 	vmlsdav.s8	r8, q1, q7
[^>]*> fef2 8e2f 	vmlsdava.s8	r8, q1, q7
[^>]*> fef2 9e0f 	vmlsdavx.s8	r8, q1, q7
[^>]*> fef2 9e2f 	vmlsdavax.s8	r8, q1, q7
[^>]*> fef4 8e01 	vmlsdav.s8	r8, q2, q0
[^>]*> fef4 8e21 	vmlsdava.s8	r8, q2, q0
[^>]*> fef4 9e01 	vmlsdavx.s8	r8, q2, q0
[^>]*> fef4 9e21 	vmlsdavax.s8	r8, q2, q0
[^>]*> fef4 8e03 	vmlsdav.s8	r8, q2, q1
[^>]*> fef4 8e23 	vmlsdava.s8	r8, q2, q1
[^>]*> fef4 9e03 	vmlsdavx.s8	r8, q2, q1
[^>]*> fef4 9e23 	vmlsdavax.s8	r8, q2, q1
[^>]*> fef4 8e05 	vmlsdav.s8	r8, q2, q2
[^>]*> fef4 8e25 	vmlsdava.s8	r8, q2, q2
[^>]*> fef4 9e05 	vmlsdavx.s8	r8, q2, q2
[^>]*> fef4 9e25 	vmlsdavax.s8	r8, q2, q2
[^>]*> fef4 8e09 	vmlsdav.s8	r8, q2, q4
[^>]*> fef4 8e29 	vmlsdava.s8	r8, q2, q4
[^>]*> fef4 9e09 	vmlsdavx.s8	r8, q2, q4
[^>]*> fef4 9e29 	vmlsdavax.s8	r8, q2, q4
[^>]*> fef4 8e0f 	vmlsdav.s8	r8, q2, q7
[^>]*> fef4 8e2f 	vmlsdava.s8	r8, q2, q7
[^>]*> fef4 9e0f 	vmlsdavx.s8	r8, q2, q7
[^>]*> fef4 9e2f 	vmlsdavax.s8	r8, q2, q7
[^>]*> fef8 8e01 	vmlsdav.s8	r8, q4, q0
[^>]*> fef8 8e21 	vmlsdava.s8	r8, q4, q0
[^>]*> fef8 9e01 	vmlsdavx.s8	r8, q4, q0
[^>]*> fef8 9e21 	vmlsdavax.s8	r8, q4, q0
[^>]*> fef8 8e03 	vmlsdav.s8	r8, q4, q1
[^>]*> fef8 8e23 	vmlsdava.s8	r8, q4, q1
[^>]*> fef8 9e03 	vmlsdavx.s8	r8, q4, q1
[^>]*> fef8 9e23 	vmlsdavax.s8	r8, q4, q1
[^>]*> fef8 8e05 	vmlsdav.s8	r8, q4, q2
[^>]*> fef8 8e25 	vmlsdava.s8	r8, q4, q2
[^>]*> fef8 9e05 	vmlsdavx.s8	r8, q4, q2
[^>]*> fef8 9e25 	vmlsdavax.s8	r8, q4, q2
[^>]*> fef8 8e09 	vmlsdav.s8	r8, q4, q4
[^>]*> fef8 8e29 	vmlsdava.s8	r8, q4, q4
[^>]*> fef8 9e09 	vmlsdavx.s8	r8, q4, q4
[^>]*> fef8 9e29 	vmlsdavax.s8	r8, q4, q4
[^>]*> fef8 8e0f 	vmlsdav.s8	r8, q4, q7
[^>]*> fef8 8e2f 	vmlsdava.s8	r8, q4, q7
[^>]*> fef8 9e0f 	vmlsdavx.s8	r8, q4, q7
[^>]*> fef8 9e2f 	vmlsdavax.s8	r8, q4, q7
[^>]*> fefe 8e01 	vmlsdav.s8	r8, q7, q0
[^>]*> fefe 8e21 	vmlsdava.s8	r8, q7, q0
[^>]*> fefe 9e01 	vmlsdavx.s8	r8, q7, q0
[^>]*> fefe 9e21 	vmlsdavax.s8	r8, q7, q0
[^>]*> fefe 8e03 	vmlsdav.s8	r8, q7, q1
[^>]*> fefe 8e23 	vmlsdava.s8	r8, q7, q1
[^>]*> fefe 9e03 	vmlsdavx.s8	r8, q7, q1
[^>]*> fefe 9e23 	vmlsdavax.s8	r8, q7, q1
[^>]*> fefe 8e05 	vmlsdav.s8	r8, q7, q2
[^>]*> fefe 8e25 	vmlsdava.s8	r8, q7, q2
[^>]*> fefe 9e05 	vmlsdavx.s8	r8, q7, q2
[^>]*> fefe 9e25 	vmlsdavax.s8	r8, q7, q2
[^>]*> fefe 8e09 	vmlsdav.s8	r8, q7, q4
[^>]*> fefe 8e29 	vmlsdava.s8	r8, q7, q4
[^>]*> fefe 9e09 	vmlsdavx.s8	r8, q7, q4
[^>]*> fefe 9e29 	vmlsdavax.s8	r8, q7, q4
[^>]*> fefe 8e0f 	vmlsdav.s8	r8, q7, q7
[^>]*> fefe 8e2f 	vmlsdava.s8	r8, q7, q7
[^>]*> fefe 9e0f 	vmlsdavx.s8	r8, q7, q7
[^>]*> fefe 9e2f 	vmlsdavax.s8	r8, q7, q7
[^>]*> fef0 ae01 	vmlsdav.s8	sl, q0, q0
[^>]*> fef0 ae21 	vmlsdava.s8	sl, q0, q0
[^>]*> fef0 be01 	vmlsdavx.s8	sl, q0, q0
[^>]*> fef0 be21 	vmlsdavax.s8	sl, q0, q0
[^>]*> fef0 ae03 	vmlsdav.s8	sl, q0, q1
[^>]*> fef0 ae23 	vmlsdava.s8	sl, q0, q1
[^>]*> fef0 be03 	vmlsdavx.s8	sl, q0, q1
[^>]*> fef0 be23 	vmlsdavax.s8	sl, q0, q1
[^>]*> fef0 ae05 	vmlsdav.s8	sl, q0, q2
[^>]*> fef0 ae25 	vmlsdava.s8	sl, q0, q2
[^>]*> fef0 be05 	vmlsdavx.s8	sl, q0, q2
[^>]*> fef0 be25 	vmlsdavax.s8	sl, q0, q2
[^>]*> fef0 ae09 	vmlsdav.s8	sl, q0, q4
[^>]*> fef0 ae29 	vmlsdava.s8	sl, q0, q4
[^>]*> fef0 be09 	vmlsdavx.s8	sl, q0, q4
[^>]*> fef0 be29 	vmlsdavax.s8	sl, q0, q4
[^>]*> fef0 ae0f 	vmlsdav.s8	sl, q0, q7
[^>]*> fef0 ae2f 	vmlsdava.s8	sl, q0, q7
[^>]*> fef0 be0f 	vmlsdavx.s8	sl, q0, q7
[^>]*> fef0 be2f 	vmlsdavax.s8	sl, q0, q7
[^>]*> fef2 ae01 	vmlsdav.s8	sl, q1, q0
[^>]*> fef2 ae21 	vmlsdava.s8	sl, q1, q0
[^>]*> fef2 be01 	vmlsdavx.s8	sl, q1, q0
[^>]*> fef2 be21 	vmlsdavax.s8	sl, q1, q0
[^>]*> fef2 ae03 	vmlsdav.s8	sl, q1, q1
[^>]*> fef2 ae23 	vmlsdava.s8	sl, q1, q1
[^>]*> fef2 be03 	vmlsdavx.s8	sl, q1, q1
[^>]*> fef2 be23 	vmlsdavax.s8	sl, q1, q1
[^>]*> fef2 ae05 	vmlsdav.s8	sl, q1, q2
[^>]*> fef2 ae25 	vmlsdava.s8	sl, q1, q2
[^>]*> fef2 be05 	vmlsdavx.s8	sl, q1, q2
[^>]*> fef2 be25 	vmlsdavax.s8	sl, q1, q2
[^>]*> fef2 ae09 	vmlsdav.s8	sl, q1, q4
[^>]*> fef2 ae29 	vmlsdava.s8	sl, q1, q4
[^>]*> fef2 be09 	vmlsdavx.s8	sl, q1, q4
[^>]*> fef2 be29 	vmlsdavax.s8	sl, q1, q4
[^>]*> fef2 ae0f 	vmlsdav.s8	sl, q1, q7
[^>]*> fef2 ae2f 	vmlsdava.s8	sl, q1, q7
[^>]*> fef2 be0f 	vmlsdavx.s8	sl, q1, q7
[^>]*> fef2 be2f 	vmlsdavax.s8	sl, q1, q7
[^>]*> fef4 ae01 	vmlsdav.s8	sl, q2, q0
[^>]*> fef4 ae21 	vmlsdava.s8	sl, q2, q0
[^>]*> fef4 be01 	vmlsdavx.s8	sl, q2, q0
[^>]*> fef4 be21 	vmlsdavax.s8	sl, q2, q0
[^>]*> fef4 ae03 	vmlsdav.s8	sl, q2, q1
[^>]*> fef4 ae23 	vmlsdava.s8	sl, q2, q1
[^>]*> fef4 be03 	vmlsdavx.s8	sl, q2, q1
[^>]*> fef4 be23 	vmlsdavax.s8	sl, q2, q1
[^>]*> fef4 ae05 	vmlsdav.s8	sl, q2, q2
[^>]*> fef4 ae25 	vmlsdava.s8	sl, q2, q2
[^>]*> fef4 be05 	vmlsdavx.s8	sl, q2, q2
[^>]*> fef4 be25 	vmlsdavax.s8	sl, q2, q2
[^>]*> fef4 ae09 	vmlsdav.s8	sl, q2, q4
[^>]*> fef4 ae29 	vmlsdava.s8	sl, q2, q4
[^>]*> fef4 be09 	vmlsdavx.s8	sl, q2, q4
[^>]*> fef4 be29 	vmlsdavax.s8	sl, q2, q4
[^>]*> fef4 ae0f 	vmlsdav.s8	sl, q2, q7
[^>]*> fef4 ae2f 	vmlsdava.s8	sl, q2, q7
[^>]*> fef4 be0f 	vmlsdavx.s8	sl, q2, q7
[^>]*> fef4 be2f 	vmlsdavax.s8	sl, q2, q7
[^>]*> fef8 ae01 	vmlsdav.s8	sl, q4, q0
[^>]*> fef8 ae21 	vmlsdava.s8	sl, q4, q0
[^>]*> fef8 be01 	vmlsdavx.s8	sl, q4, q0
[^>]*> fef8 be21 	vmlsdavax.s8	sl, q4, q0
[^>]*> fef8 ae03 	vmlsdav.s8	sl, q4, q1
[^>]*> fef8 ae23 	vmlsdava.s8	sl, q4, q1
[^>]*> fef8 be03 	vmlsdavx.s8	sl, q4, q1
[^>]*> fef8 be23 	vmlsdavax.s8	sl, q4, q1
[^>]*> fef8 ae05 	vmlsdav.s8	sl, q4, q2
[^>]*> fef8 ae25 	vmlsdava.s8	sl, q4, q2
[^>]*> fef8 be05 	vmlsdavx.s8	sl, q4, q2
[^>]*> fef8 be25 	vmlsdavax.s8	sl, q4, q2
[^>]*> fef8 ae09 	vmlsdav.s8	sl, q4, q4
[^>]*> fef8 ae29 	vmlsdava.s8	sl, q4, q4
[^>]*> fef8 be09 	vmlsdavx.s8	sl, q4, q4
[^>]*> fef8 be29 	vmlsdavax.s8	sl, q4, q4
[^>]*> fef8 ae0f 	vmlsdav.s8	sl, q4, q7
[^>]*> fef8 ae2f 	vmlsdava.s8	sl, q4, q7
[^>]*> fef8 be0f 	vmlsdavx.s8	sl, q4, q7
[^>]*> fef8 be2f 	vmlsdavax.s8	sl, q4, q7
[^>]*> fefe ae01 	vmlsdav.s8	sl, q7, q0
[^>]*> fefe ae21 	vmlsdava.s8	sl, q7, q0
[^>]*> fefe be01 	vmlsdavx.s8	sl, q7, q0
[^>]*> fefe be21 	vmlsdavax.s8	sl, q7, q0
[^>]*> fefe ae03 	vmlsdav.s8	sl, q7, q1
[^>]*> fefe ae23 	vmlsdava.s8	sl, q7, q1
[^>]*> fefe be03 	vmlsdavx.s8	sl, q7, q1
[^>]*> fefe be23 	vmlsdavax.s8	sl, q7, q1
[^>]*> fefe ae05 	vmlsdav.s8	sl, q7, q2
[^>]*> fefe ae25 	vmlsdava.s8	sl, q7, q2
[^>]*> fefe be05 	vmlsdavx.s8	sl, q7, q2
[^>]*> fefe be25 	vmlsdavax.s8	sl, q7, q2
[^>]*> fefe ae09 	vmlsdav.s8	sl, q7, q4
[^>]*> fefe ae29 	vmlsdava.s8	sl, q7, q4
[^>]*> fefe be09 	vmlsdavx.s8	sl, q7, q4
[^>]*> fefe be29 	vmlsdavax.s8	sl, q7, q4
[^>]*> fefe ae0f 	vmlsdav.s8	sl, q7, q7
[^>]*> fefe ae2f 	vmlsdava.s8	sl, q7, q7
[^>]*> fefe be0f 	vmlsdavx.s8	sl, q7, q7
[^>]*> fefe be2f 	vmlsdavax.s8	sl, q7, q7
[^>]*> fef0 ce01 	vmlsdav.s8	ip, q0, q0
[^>]*> fef0 ce21 	vmlsdava.s8	ip, q0, q0
[^>]*> fef0 de01 	vmlsdavx.s8	ip, q0, q0
[^>]*> fef0 de21 	vmlsdavax.s8	ip, q0, q0
[^>]*> fef0 ce03 	vmlsdav.s8	ip, q0, q1
[^>]*> fef0 ce23 	vmlsdava.s8	ip, q0, q1
[^>]*> fef0 de03 	vmlsdavx.s8	ip, q0, q1
[^>]*> fef0 de23 	vmlsdavax.s8	ip, q0, q1
[^>]*> fef0 ce05 	vmlsdav.s8	ip, q0, q2
[^>]*> fef0 ce25 	vmlsdava.s8	ip, q0, q2
[^>]*> fef0 de05 	vmlsdavx.s8	ip, q0, q2
[^>]*> fef0 de25 	vmlsdavax.s8	ip, q0, q2
[^>]*> fef0 ce09 	vmlsdav.s8	ip, q0, q4
[^>]*> fef0 ce29 	vmlsdava.s8	ip, q0, q4
[^>]*> fef0 de09 	vmlsdavx.s8	ip, q0, q4
[^>]*> fef0 de29 	vmlsdavax.s8	ip, q0, q4
[^>]*> fef0 ce0f 	vmlsdav.s8	ip, q0, q7
[^>]*> fef0 ce2f 	vmlsdava.s8	ip, q0, q7
[^>]*> fef0 de0f 	vmlsdavx.s8	ip, q0, q7
[^>]*> fef0 de2f 	vmlsdavax.s8	ip, q0, q7
[^>]*> fef2 ce01 	vmlsdav.s8	ip, q1, q0
[^>]*> fef2 ce21 	vmlsdava.s8	ip, q1, q0
[^>]*> fef2 de01 	vmlsdavx.s8	ip, q1, q0
[^>]*> fef2 de21 	vmlsdavax.s8	ip, q1, q0
[^>]*> fef2 ce03 	vmlsdav.s8	ip, q1, q1
[^>]*> fef2 ce23 	vmlsdava.s8	ip, q1, q1
[^>]*> fef2 de03 	vmlsdavx.s8	ip, q1, q1
[^>]*> fef2 de23 	vmlsdavax.s8	ip, q1, q1
[^>]*> fef2 ce05 	vmlsdav.s8	ip, q1, q2
[^>]*> fef2 ce25 	vmlsdava.s8	ip, q1, q2
[^>]*> fef2 de05 	vmlsdavx.s8	ip, q1, q2
[^>]*> fef2 de25 	vmlsdavax.s8	ip, q1, q2
[^>]*> fef2 ce09 	vmlsdav.s8	ip, q1, q4
[^>]*> fef2 ce29 	vmlsdava.s8	ip, q1, q4
[^>]*> fef2 de09 	vmlsdavx.s8	ip, q1, q4
[^>]*> fef2 de29 	vmlsdavax.s8	ip, q1, q4
[^>]*> fef2 ce0f 	vmlsdav.s8	ip, q1, q7
[^>]*> fef2 ce2f 	vmlsdava.s8	ip, q1, q7
[^>]*> fef2 de0f 	vmlsdavx.s8	ip, q1, q7
[^>]*> fef2 de2f 	vmlsdavax.s8	ip, q1, q7
[^>]*> fef4 ce01 	vmlsdav.s8	ip, q2, q0
[^>]*> fef4 ce21 	vmlsdava.s8	ip, q2, q0
[^>]*> fef4 de01 	vmlsdavx.s8	ip, q2, q0
[^>]*> fef4 de21 	vmlsdavax.s8	ip, q2, q0
[^>]*> fef4 ce03 	vmlsdav.s8	ip, q2, q1
[^>]*> fef4 ce23 	vmlsdava.s8	ip, q2, q1
[^>]*> fef4 de03 	vmlsdavx.s8	ip, q2, q1
[^>]*> fef4 de23 	vmlsdavax.s8	ip, q2, q1
[^>]*> fef4 ce05 	vmlsdav.s8	ip, q2, q2
[^>]*> fef4 ce25 	vmlsdava.s8	ip, q2, q2
[^>]*> fef4 de05 	vmlsdavx.s8	ip, q2, q2
[^>]*> fef4 de25 	vmlsdavax.s8	ip, q2, q2
[^>]*> fef4 ce09 	vmlsdav.s8	ip, q2, q4
[^>]*> fef4 ce29 	vmlsdava.s8	ip, q2, q4
[^>]*> fef4 de09 	vmlsdavx.s8	ip, q2, q4
[^>]*> fef4 de29 	vmlsdavax.s8	ip, q2, q4
[^>]*> fef4 ce0f 	vmlsdav.s8	ip, q2, q7
[^>]*> fef4 ce2f 	vmlsdava.s8	ip, q2, q7
[^>]*> fef4 de0f 	vmlsdavx.s8	ip, q2, q7
[^>]*> fef4 de2f 	vmlsdavax.s8	ip, q2, q7
[^>]*> fef8 ce01 	vmlsdav.s8	ip, q4, q0
[^>]*> fef8 ce21 	vmlsdava.s8	ip, q4, q0
[^>]*> fef8 de01 	vmlsdavx.s8	ip, q4, q0
[^>]*> fef8 de21 	vmlsdavax.s8	ip, q4, q0
[^>]*> fef8 ce03 	vmlsdav.s8	ip, q4, q1
[^>]*> fef8 ce23 	vmlsdava.s8	ip, q4, q1
[^>]*> fef8 de03 	vmlsdavx.s8	ip, q4, q1
[^>]*> fef8 de23 	vmlsdavax.s8	ip, q4, q1
[^>]*> fef8 ce05 	vmlsdav.s8	ip, q4, q2
[^>]*> fef8 ce25 	vmlsdava.s8	ip, q4, q2
[^>]*> fef8 de05 	vmlsdavx.s8	ip, q4, q2
[^>]*> fef8 de25 	vmlsdavax.s8	ip, q4, q2
[^>]*> fef8 ce09 	vmlsdav.s8	ip, q4, q4
[^>]*> fef8 ce29 	vmlsdava.s8	ip, q4, q4
[^>]*> fef8 de09 	vmlsdavx.s8	ip, q4, q4
[^>]*> fef8 de29 	vmlsdavax.s8	ip, q4, q4
[^>]*> fef8 ce0f 	vmlsdav.s8	ip, q4, q7
[^>]*> fef8 ce2f 	vmlsdava.s8	ip, q4, q7
[^>]*> fef8 de0f 	vmlsdavx.s8	ip, q4, q7
[^>]*> fef8 de2f 	vmlsdavax.s8	ip, q4, q7
[^>]*> fefe ce01 	vmlsdav.s8	ip, q7, q0
[^>]*> fefe ce21 	vmlsdava.s8	ip, q7, q0
[^>]*> fefe de01 	vmlsdavx.s8	ip, q7, q0
[^>]*> fefe de21 	vmlsdavax.s8	ip, q7, q0
[^>]*> fefe ce03 	vmlsdav.s8	ip, q7, q1
[^>]*> fefe ce23 	vmlsdava.s8	ip, q7, q1
[^>]*> fefe de03 	vmlsdavx.s8	ip, q7, q1
[^>]*> fefe de23 	vmlsdavax.s8	ip, q7, q1
[^>]*> fefe ce05 	vmlsdav.s8	ip, q7, q2
[^>]*> fefe ce25 	vmlsdava.s8	ip, q7, q2
[^>]*> fefe de05 	vmlsdavx.s8	ip, q7, q2
[^>]*> fefe de25 	vmlsdavax.s8	ip, q7, q2
[^>]*> fefe ce09 	vmlsdav.s8	ip, q7, q4
[^>]*> fefe ce29 	vmlsdava.s8	ip, q7, q4
[^>]*> fefe de09 	vmlsdavx.s8	ip, q7, q4
[^>]*> fefe de29 	vmlsdavax.s8	ip, q7, q4
[^>]*> fefe ce0f 	vmlsdav.s8	ip, q7, q7
[^>]*> fefe ce2f 	vmlsdava.s8	ip, q7, q7
[^>]*> fefe de0f 	vmlsdavx.s8	ip, q7, q7
[^>]*> fefe de2f 	vmlsdavax.s8	ip, q7, q7
[^>]*> fef0 ee01 	vmlsdav.s8	lr, q0, q0
[^>]*> fef0 ee21 	vmlsdava.s8	lr, q0, q0
[^>]*> fef0 fe01 	vmlsdavx.s8	lr, q0, q0
[^>]*> fef0 fe21 	vmlsdavax.s8	lr, q0, q0
[^>]*> fef0 ee03 	vmlsdav.s8	lr, q0, q1
[^>]*> fef0 ee23 	vmlsdava.s8	lr, q0, q1
[^>]*> fef0 fe03 	vmlsdavx.s8	lr, q0, q1
[^>]*> fef0 fe23 	vmlsdavax.s8	lr, q0, q1
[^>]*> fef0 ee05 	vmlsdav.s8	lr, q0, q2
[^>]*> fef0 ee25 	vmlsdava.s8	lr, q0, q2
[^>]*> fef0 fe05 	vmlsdavx.s8	lr, q0, q2
[^>]*> fef0 fe25 	vmlsdavax.s8	lr, q0, q2
[^>]*> fef0 ee09 	vmlsdav.s8	lr, q0, q4
[^>]*> fef0 ee29 	vmlsdava.s8	lr, q0, q4
[^>]*> fef0 fe09 	vmlsdavx.s8	lr, q0, q4
[^>]*> fef0 fe29 	vmlsdavax.s8	lr, q0, q4
[^>]*> fef0 ee0f 	vmlsdav.s8	lr, q0, q7
[^>]*> fef0 ee2f 	vmlsdava.s8	lr, q0, q7
[^>]*> fef0 fe0f 	vmlsdavx.s8	lr, q0, q7
[^>]*> fef0 fe2f 	vmlsdavax.s8	lr, q0, q7
[^>]*> fef2 ee01 	vmlsdav.s8	lr, q1, q0
[^>]*> fef2 ee21 	vmlsdava.s8	lr, q1, q0
[^>]*> fef2 fe01 	vmlsdavx.s8	lr, q1, q0
[^>]*> fef2 fe21 	vmlsdavax.s8	lr, q1, q0
[^>]*> fef2 ee03 	vmlsdav.s8	lr, q1, q1
[^>]*> fef2 ee23 	vmlsdava.s8	lr, q1, q1
[^>]*> fef2 fe03 	vmlsdavx.s8	lr, q1, q1
[^>]*> fef2 fe23 	vmlsdavax.s8	lr, q1, q1
[^>]*> fef2 ee05 	vmlsdav.s8	lr, q1, q2
[^>]*> fef2 ee25 	vmlsdava.s8	lr, q1, q2
[^>]*> fef2 fe05 	vmlsdavx.s8	lr, q1, q2
[^>]*> fef2 fe25 	vmlsdavax.s8	lr, q1, q2
[^>]*> fef2 ee09 	vmlsdav.s8	lr, q1, q4
[^>]*> fef2 ee29 	vmlsdava.s8	lr, q1, q4
[^>]*> fef2 fe09 	vmlsdavx.s8	lr, q1, q4
[^>]*> fef2 fe29 	vmlsdavax.s8	lr, q1, q4
[^>]*> fef2 ee0f 	vmlsdav.s8	lr, q1, q7
[^>]*> fef2 ee2f 	vmlsdava.s8	lr, q1, q7
[^>]*> fef2 fe0f 	vmlsdavx.s8	lr, q1, q7
[^>]*> fef2 fe2f 	vmlsdavax.s8	lr, q1, q7
[^>]*> fef4 ee01 	vmlsdav.s8	lr, q2, q0
[^>]*> fef4 ee21 	vmlsdava.s8	lr, q2, q0
[^>]*> fef4 fe01 	vmlsdavx.s8	lr, q2, q0
[^>]*> fef4 fe21 	vmlsdavax.s8	lr, q2, q0
[^>]*> fef4 ee03 	vmlsdav.s8	lr, q2, q1
[^>]*> fef4 ee23 	vmlsdava.s8	lr, q2, q1
[^>]*> fef4 fe03 	vmlsdavx.s8	lr, q2, q1
[^>]*> fef4 fe23 	vmlsdavax.s8	lr, q2, q1
[^>]*> fef4 ee05 	vmlsdav.s8	lr, q2, q2
[^>]*> fef4 ee25 	vmlsdava.s8	lr, q2, q2
[^>]*> fef4 fe05 	vmlsdavx.s8	lr, q2, q2
[^>]*> fef4 fe25 	vmlsdavax.s8	lr, q2, q2
[^>]*> fef4 ee09 	vmlsdav.s8	lr, q2, q4
[^>]*> fef4 ee29 	vmlsdava.s8	lr, q2, q4
[^>]*> fef4 fe09 	vmlsdavx.s8	lr, q2, q4
[^>]*> fef4 fe29 	vmlsdavax.s8	lr, q2, q4
[^>]*> fef4 ee0f 	vmlsdav.s8	lr, q2, q7
[^>]*> fef4 ee2f 	vmlsdava.s8	lr, q2, q7
[^>]*> fef4 fe0f 	vmlsdavx.s8	lr, q2, q7
[^>]*> fef4 fe2f 	vmlsdavax.s8	lr, q2, q7
[^>]*> fef8 ee01 	vmlsdav.s8	lr, q4, q0
[^>]*> fef8 ee21 	vmlsdava.s8	lr, q4, q0
[^>]*> fef8 fe01 	vmlsdavx.s8	lr, q4, q0
[^>]*> fef8 fe21 	vmlsdavax.s8	lr, q4, q0
[^>]*> fef8 ee03 	vmlsdav.s8	lr, q4, q1
[^>]*> fef8 ee23 	vmlsdava.s8	lr, q4, q1
[^>]*> fef8 fe03 	vmlsdavx.s8	lr, q4, q1
[^>]*> fef8 fe23 	vmlsdavax.s8	lr, q4, q1
[^>]*> fef8 ee05 	vmlsdav.s8	lr, q4, q2
[^>]*> fef8 ee25 	vmlsdava.s8	lr, q4, q2
[^>]*> fef8 fe05 	vmlsdavx.s8	lr, q4, q2
[^>]*> fef8 fe25 	vmlsdavax.s8	lr, q4, q2
[^>]*> fef8 ee09 	vmlsdav.s8	lr, q4, q4
[^>]*> fef8 ee29 	vmlsdava.s8	lr, q4, q4
[^>]*> fef8 fe09 	vmlsdavx.s8	lr, q4, q4
[^>]*> fef8 fe29 	vmlsdavax.s8	lr, q4, q4
[^>]*> fef8 ee0f 	vmlsdav.s8	lr, q4, q7
[^>]*> fef8 ee2f 	vmlsdava.s8	lr, q4, q7
[^>]*> fef8 fe0f 	vmlsdavx.s8	lr, q4, q7
[^>]*> fef8 fe2f 	vmlsdavax.s8	lr, q4, q7
[^>]*> fefe ee01 	vmlsdav.s8	lr, q7, q0
[^>]*> fefe ee21 	vmlsdava.s8	lr, q7, q0
[^>]*> fefe fe01 	vmlsdavx.s8	lr, q7, q0
[^>]*> fefe fe21 	vmlsdavax.s8	lr, q7, q0
[^>]*> fefe ee03 	vmlsdav.s8	lr, q7, q1
[^>]*> fefe ee23 	vmlsdava.s8	lr, q7, q1
[^>]*> fefe fe03 	vmlsdavx.s8	lr, q7, q1
[^>]*> fefe fe23 	vmlsdavax.s8	lr, q7, q1
[^>]*> fefe ee05 	vmlsdav.s8	lr, q7, q2
[^>]*> fefe ee25 	vmlsdava.s8	lr, q7, q2
[^>]*> fefe fe05 	vmlsdavx.s8	lr, q7, q2
[^>]*> fefe fe25 	vmlsdavax.s8	lr, q7, q2
[^>]*> fefe ee09 	vmlsdav.s8	lr, q7, q4
[^>]*> fefe ee29 	vmlsdava.s8	lr, q7, q4
[^>]*> fefe fe09 	vmlsdavx.s8	lr, q7, q4
[^>]*> fefe fe29 	vmlsdavax.s8	lr, q7, q4
[^>]*> fefe ee0f 	vmlsdav.s8	lr, q7, q7
[^>]*> fefe ee2f 	vmlsdava.s8	lr, q7, q7
[^>]*> fefe fe0f 	vmlsdavx.s8	lr, q7, q7
[^>]*> fefe fe2f 	vmlsdavax.s8	lr, q7, q7
[^>]*> eef0 0e01 	vmlsdav.s16	r0, q0, q0
[^>]*> eef0 0e21 	vmlsdava.s16	r0, q0, q0
[^>]*> eef0 1e01 	vmlsdavx.s16	r0, q0, q0
[^>]*> eef0 1e21 	vmlsdavax.s16	r0, q0, q0
[^>]*> eef0 0e03 	vmlsdav.s16	r0, q0, q1
[^>]*> eef0 0e23 	vmlsdava.s16	r0, q0, q1
[^>]*> eef0 1e03 	vmlsdavx.s16	r0, q0, q1
[^>]*> eef0 1e23 	vmlsdavax.s16	r0, q0, q1
[^>]*> eef0 0e05 	vmlsdav.s16	r0, q0, q2
[^>]*> eef0 0e25 	vmlsdava.s16	r0, q0, q2
[^>]*> eef0 1e05 	vmlsdavx.s16	r0, q0, q2
[^>]*> eef0 1e25 	vmlsdavax.s16	r0, q0, q2
[^>]*> eef0 0e09 	vmlsdav.s16	r0, q0, q4
[^>]*> eef0 0e29 	vmlsdava.s16	r0, q0, q4
[^>]*> eef0 1e09 	vmlsdavx.s16	r0, q0, q4
[^>]*> eef0 1e29 	vmlsdavax.s16	r0, q0, q4
[^>]*> eef0 0e0f 	vmlsdav.s16	r0, q0, q7
[^>]*> eef0 0e2f 	vmlsdava.s16	r0, q0, q7
[^>]*> eef0 1e0f 	vmlsdavx.s16	r0, q0, q7
[^>]*> eef0 1e2f 	vmlsdavax.s16	r0, q0, q7
[^>]*> eef2 0e01 	vmlsdav.s16	r0, q1, q0
[^>]*> eef2 0e21 	vmlsdava.s16	r0, q1, q0
[^>]*> eef2 1e01 	vmlsdavx.s16	r0, q1, q0
[^>]*> eef2 1e21 	vmlsdavax.s16	r0, q1, q0
[^>]*> eef2 0e03 	vmlsdav.s16	r0, q1, q1
[^>]*> eef2 0e23 	vmlsdava.s16	r0, q1, q1
[^>]*> eef2 1e03 	vmlsdavx.s16	r0, q1, q1
[^>]*> eef2 1e23 	vmlsdavax.s16	r0, q1, q1
[^>]*> eef2 0e05 	vmlsdav.s16	r0, q1, q2
[^>]*> eef2 0e25 	vmlsdava.s16	r0, q1, q2
[^>]*> eef2 1e05 	vmlsdavx.s16	r0, q1, q2
[^>]*> eef2 1e25 	vmlsdavax.s16	r0, q1, q2
[^>]*> eef2 0e09 	vmlsdav.s16	r0, q1, q4
[^>]*> eef2 0e29 	vmlsdava.s16	r0, q1, q4
[^>]*> eef2 1e09 	vmlsdavx.s16	r0, q1, q4
[^>]*> eef2 1e29 	vmlsdavax.s16	r0, q1, q4
[^>]*> eef2 0e0f 	vmlsdav.s16	r0, q1, q7
[^>]*> eef2 0e2f 	vmlsdava.s16	r0, q1, q7
[^>]*> eef2 1e0f 	vmlsdavx.s16	r0, q1, q7
[^>]*> eef2 1e2f 	vmlsdavax.s16	r0, q1, q7
[^>]*> eef4 0e01 	vmlsdav.s16	r0, q2, q0
[^>]*> eef4 0e21 	vmlsdava.s16	r0, q2, q0
[^>]*> eef4 1e01 	vmlsdavx.s16	r0, q2, q0
[^>]*> eef4 1e21 	vmlsdavax.s16	r0, q2, q0
[^>]*> eef4 0e03 	vmlsdav.s16	r0, q2, q1
[^>]*> eef4 0e23 	vmlsdava.s16	r0, q2, q1
[^>]*> eef4 1e03 	vmlsdavx.s16	r0, q2, q1
[^>]*> eef4 1e23 	vmlsdavax.s16	r0, q2, q1
[^>]*> eef4 0e05 	vmlsdav.s16	r0, q2, q2
[^>]*> eef4 0e25 	vmlsdava.s16	r0, q2, q2
[^>]*> eef4 1e05 	vmlsdavx.s16	r0, q2, q2
[^>]*> eef4 1e25 	vmlsdavax.s16	r0, q2, q2
[^>]*> eef4 0e09 	vmlsdav.s16	r0, q2, q4
[^>]*> eef4 0e29 	vmlsdava.s16	r0, q2, q4
[^>]*> eef4 1e09 	vmlsdavx.s16	r0, q2, q4
[^>]*> eef4 1e29 	vmlsdavax.s16	r0, q2, q4
[^>]*> eef4 0e0f 	vmlsdav.s16	r0, q2, q7
[^>]*> eef4 0e2f 	vmlsdava.s16	r0, q2, q7
[^>]*> eef4 1e0f 	vmlsdavx.s16	r0, q2, q7
[^>]*> eef4 1e2f 	vmlsdavax.s16	r0, q2, q7
[^>]*> eef8 0e01 	vmlsdav.s16	r0, q4, q0
[^>]*> eef8 0e21 	vmlsdava.s16	r0, q4, q0
[^>]*> eef8 1e01 	vmlsdavx.s16	r0, q4, q0
[^>]*> eef8 1e21 	vmlsdavax.s16	r0, q4, q0
[^>]*> eef8 0e03 	vmlsdav.s16	r0, q4, q1
[^>]*> eef8 0e23 	vmlsdava.s16	r0, q4, q1
[^>]*> eef8 1e03 	vmlsdavx.s16	r0, q4, q1
[^>]*> eef8 1e23 	vmlsdavax.s16	r0, q4, q1
[^>]*> eef8 0e05 	vmlsdav.s16	r0, q4, q2
[^>]*> eef8 0e25 	vmlsdava.s16	r0, q4, q2
[^>]*> eef8 1e05 	vmlsdavx.s16	r0, q4, q2
[^>]*> eef8 1e25 	vmlsdavax.s16	r0, q4, q2
[^>]*> eef8 0e09 	vmlsdav.s16	r0, q4, q4
[^>]*> eef8 0e29 	vmlsdava.s16	r0, q4, q4
[^>]*> eef8 1e09 	vmlsdavx.s16	r0, q4, q4
[^>]*> eef8 1e29 	vmlsdavax.s16	r0, q4, q4
[^>]*> eef8 0e0f 	vmlsdav.s16	r0, q4, q7
[^>]*> eef8 0e2f 	vmlsdava.s16	r0, q4, q7
[^>]*> eef8 1e0f 	vmlsdavx.s16	r0, q4, q7
[^>]*> eef8 1e2f 	vmlsdavax.s16	r0, q4, q7
[^>]*> eefe 0e01 	vmlsdav.s16	r0, q7, q0
[^>]*> eefe 0e21 	vmlsdava.s16	r0, q7, q0
[^>]*> eefe 1e01 	vmlsdavx.s16	r0, q7, q0
[^>]*> eefe 1e21 	vmlsdavax.s16	r0, q7, q0
[^>]*> eefe 0e03 	vmlsdav.s16	r0, q7, q1
[^>]*> eefe 0e23 	vmlsdava.s16	r0, q7, q1
[^>]*> eefe 1e03 	vmlsdavx.s16	r0, q7, q1
[^>]*> eefe 1e23 	vmlsdavax.s16	r0, q7, q1
[^>]*> eefe 0e05 	vmlsdav.s16	r0, q7, q2
[^>]*> eefe 0e25 	vmlsdava.s16	r0, q7, q2
[^>]*> eefe 1e05 	vmlsdavx.s16	r0, q7, q2
[^>]*> eefe 1e25 	vmlsdavax.s16	r0, q7, q2
[^>]*> eefe 0e09 	vmlsdav.s16	r0, q7, q4
[^>]*> eefe 0e29 	vmlsdava.s16	r0, q7, q4
[^>]*> eefe 1e09 	vmlsdavx.s16	r0, q7, q4
[^>]*> eefe 1e29 	vmlsdavax.s16	r0, q7, q4
[^>]*> eefe 0e0f 	vmlsdav.s16	r0, q7, q7
[^>]*> eefe 0e2f 	vmlsdava.s16	r0, q7, q7
[^>]*> eefe 1e0f 	vmlsdavx.s16	r0, q7, q7
[^>]*> eefe 1e2f 	vmlsdavax.s16	r0, q7, q7
[^>]*> eef0 2e01 	vmlsdav.s16	r2, q0, q0
[^>]*> eef0 2e21 	vmlsdava.s16	r2, q0, q0
[^>]*> eef0 3e01 	vmlsdavx.s16	r2, q0, q0
[^>]*> eef0 3e21 	vmlsdavax.s16	r2, q0, q0
[^>]*> eef0 2e03 	vmlsdav.s16	r2, q0, q1
[^>]*> eef0 2e23 	vmlsdava.s16	r2, q0, q1
[^>]*> eef0 3e03 	vmlsdavx.s16	r2, q0, q1
[^>]*> eef0 3e23 	vmlsdavax.s16	r2, q0, q1
[^>]*> eef0 2e05 	vmlsdav.s16	r2, q0, q2
[^>]*> eef0 2e25 	vmlsdava.s16	r2, q0, q2
[^>]*> eef0 3e05 	vmlsdavx.s16	r2, q0, q2
[^>]*> eef0 3e25 	vmlsdavax.s16	r2, q0, q2
[^>]*> eef0 2e09 	vmlsdav.s16	r2, q0, q4
[^>]*> eef0 2e29 	vmlsdava.s16	r2, q0, q4
[^>]*> eef0 3e09 	vmlsdavx.s16	r2, q0, q4
[^>]*> eef0 3e29 	vmlsdavax.s16	r2, q0, q4
[^>]*> eef0 2e0f 	vmlsdav.s16	r2, q0, q7
[^>]*> eef0 2e2f 	vmlsdava.s16	r2, q0, q7
[^>]*> eef0 3e0f 	vmlsdavx.s16	r2, q0, q7
[^>]*> eef0 3e2f 	vmlsdavax.s16	r2, q0, q7
[^>]*> eef2 2e01 	vmlsdav.s16	r2, q1, q0
[^>]*> eef2 2e21 	vmlsdava.s16	r2, q1, q0
[^>]*> eef2 3e01 	vmlsdavx.s16	r2, q1, q0
[^>]*> eef2 3e21 	vmlsdavax.s16	r2, q1, q0
[^>]*> eef2 2e03 	vmlsdav.s16	r2, q1, q1
[^>]*> eef2 2e23 	vmlsdava.s16	r2, q1, q1
[^>]*> eef2 3e03 	vmlsdavx.s16	r2, q1, q1
[^>]*> eef2 3e23 	vmlsdavax.s16	r2, q1, q1
[^>]*> eef2 2e05 	vmlsdav.s16	r2, q1, q2
[^>]*> eef2 2e25 	vmlsdava.s16	r2, q1, q2
[^>]*> eef2 3e05 	vmlsdavx.s16	r2, q1, q2
[^>]*> eef2 3e25 	vmlsdavax.s16	r2, q1, q2
[^>]*> eef2 2e09 	vmlsdav.s16	r2, q1, q4
[^>]*> eef2 2e29 	vmlsdava.s16	r2, q1, q4
[^>]*> eef2 3e09 	vmlsdavx.s16	r2, q1, q4
[^>]*> eef2 3e29 	vmlsdavax.s16	r2, q1, q4
[^>]*> eef2 2e0f 	vmlsdav.s16	r2, q1, q7
[^>]*> eef2 2e2f 	vmlsdava.s16	r2, q1, q7
[^>]*> eef2 3e0f 	vmlsdavx.s16	r2, q1, q7
[^>]*> eef2 3e2f 	vmlsdavax.s16	r2, q1, q7
[^>]*> eef4 2e01 	vmlsdav.s16	r2, q2, q0
[^>]*> eef4 2e21 	vmlsdava.s16	r2, q2, q0
[^>]*> eef4 3e01 	vmlsdavx.s16	r2, q2, q0
[^>]*> eef4 3e21 	vmlsdavax.s16	r2, q2, q0
[^>]*> eef4 2e03 	vmlsdav.s16	r2, q2, q1
[^>]*> eef4 2e23 	vmlsdava.s16	r2, q2, q1
[^>]*> eef4 3e03 	vmlsdavx.s16	r2, q2, q1
[^>]*> eef4 3e23 	vmlsdavax.s16	r2, q2, q1
[^>]*> eef4 2e05 	vmlsdav.s16	r2, q2, q2
[^>]*> eef4 2e25 	vmlsdava.s16	r2, q2, q2
[^>]*> eef4 3e05 	vmlsdavx.s16	r2, q2, q2
[^>]*> eef4 3e25 	vmlsdavax.s16	r2, q2, q2
[^>]*> eef4 2e09 	vmlsdav.s16	r2, q2, q4
[^>]*> eef4 2e29 	vmlsdava.s16	r2, q2, q4
[^>]*> eef4 3e09 	vmlsdavx.s16	r2, q2, q4
[^>]*> eef4 3e29 	vmlsdavax.s16	r2, q2, q4
[^>]*> eef4 2e0f 	vmlsdav.s16	r2, q2, q7
[^>]*> eef4 2e2f 	vmlsdava.s16	r2, q2, q7
[^>]*> eef4 3e0f 	vmlsdavx.s16	r2, q2, q7
[^>]*> eef4 3e2f 	vmlsdavax.s16	r2, q2, q7
[^>]*> eef8 2e01 	vmlsdav.s16	r2, q4, q0
[^>]*> eef8 2e21 	vmlsdava.s16	r2, q4, q0
[^>]*> eef8 3e01 	vmlsdavx.s16	r2, q4, q0
[^>]*> eef8 3e21 	vmlsdavax.s16	r2, q4, q0
[^>]*> eef8 2e03 	vmlsdav.s16	r2, q4, q1
[^>]*> eef8 2e23 	vmlsdava.s16	r2, q4, q1
[^>]*> eef8 3e03 	vmlsdavx.s16	r2, q4, q1
[^>]*> eef8 3e23 	vmlsdavax.s16	r2, q4, q1
[^>]*> eef8 2e05 	vmlsdav.s16	r2, q4, q2
[^>]*> eef8 2e25 	vmlsdava.s16	r2, q4, q2
[^>]*> eef8 3e05 	vmlsdavx.s16	r2, q4, q2
[^>]*> eef8 3e25 	vmlsdavax.s16	r2, q4, q2
[^>]*> eef8 2e09 	vmlsdav.s16	r2, q4, q4
[^>]*> eef8 2e29 	vmlsdava.s16	r2, q4, q4
[^>]*> eef8 3e09 	vmlsdavx.s16	r2, q4, q4
[^>]*> eef8 3e29 	vmlsdavax.s16	r2, q4, q4
[^>]*> eef8 2e0f 	vmlsdav.s16	r2, q4, q7
[^>]*> eef8 2e2f 	vmlsdava.s16	r2, q4, q7
[^>]*> eef8 3e0f 	vmlsdavx.s16	r2, q4, q7
[^>]*> eef8 3e2f 	vmlsdavax.s16	r2, q4, q7
[^>]*> eefe 2e01 	vmlsdav.s16	r2, q7, q0
[^>]*> eefe 2e21 	vmlsdava.s16	r2, q7, q0
[^>]*> eefe 3e01 	vmlsdavx.s16	r2, q7, q0
[^>]*> eefe 3e21 	vmlsdavax.s16	r2, q7, q0
[^>]*> eefe 2e03 	vmlsdav.s16	r2, q7, q1
[^>]*> eefe 2e23 	vmlsdava.s16	r2, q7, q1
[^>]*> eefe 3e03 	vmlsdavx.s16	r2, q7, q1
[^>]*> eefe 3e23 	vmlsdavax.s16	r2, q7, q1
[^>]*> eefe 2e05 	vmlsdav.s16	r2, q7, q2
[^>]*> eefe 2e25 	vmlsdava.s16	r2, q7, q2
[^>]*> eefe 3e05 	vmlsdavx.s16	r2, q7, q2
[^>]*> eefe 3e25 	vmlsdavax.s16	r2, q7, q2
[^>]*> eefe 2e09 	vmlsdav.s16	r2, q7, q4
[^>]*> eefe 2e29 	vmlsdava.s16	r2, q7, q4
[^>]*> eefe 3e09 	vmlsdavx.s16	r2, q7, q4
[^>]*> eefe 3e29 	vmlsdavax.s16	r2, q7, q4
[^>]*> eefe 2e0f 	vmlsdav.s16	r2, q7, q7
[^>]*> eefe 2e2f 	vmlsdava.s16	r2, q7, q7
[^>]*> eefe 3e0f 	vmlsdavx.s16	r2, q7, q7
[^>]*> eefe 3e2f 	vmlsdavax.s16	r2, q7, q7
[^>]*> eef0 4e01 	vmlsdav.s16	r4, q0, q0
[^>]*> eef0 4e21 	vmlsdava.s16	r4, q0, q0
[^>]*> eef0 5e01 	vmlsdavx.s16	r4, q0, q0
[^>]*> eef0 5e21 	vmlsdavax.s16	r4, q0, q0
[^>]*> eef0 4e03 	vmlsdav.s16	r4, q0, q1
[^>]*> eef0 4e23 	vmlsdava.s16	r4, q0, q1
[^>]*> eef0 5e03 	vmlsdavx.s16	r4, q0, q1
[^>]*> eef0 5e23 	vmlsdavax.s16	r4, q0, q1
[^>]*> eef0 4e05 	vmlsdav.s16	r4, q0, q2
[^>]*> eef0 4e25 	vmlsdava.s16	r4, q0, q2
[^>]*> eef0 5e05 	vmlsdavx.s16	r4, q0, q2
[^>]*> eef0 5e25 	vmlsdavax.s16	r4, q0, q2
[^>]*> eef0 4e09 	vmlsdav.s16	r4, q0, q4
[^>]*> eef0 4e29 	vmlsdava.s16	r4, q0, q4
[^>]*> eef0 5e09 	vmlsdavx.s16	r4, q0, q4
[^>]*> eef0 5e29 	vmlsdavax.s16	r4, q0, q4
[^>]*> eef0 4e0f 	vmlsdav.s16	r4, q0, q7
[^>]*> eef0 4e2f 	vmlsdava.s16	r4, q0, q7
[^>]*> eef0 5e0f 	vmlsdavx.s16	r4, q0, q7
[^>]*> eef0 5e2f 	vmlsdavax.s16	r4, q0, q7
[^>]*> eef2 4e01 	vmlsdav.s16	r4, q1, q0
[^>]*> eef2 4e21 	vmlsdava.s16	r4, q1, q0
[^>]*> eef2 5e01 	vmlsdavx.s16	r4, q1, q0
[^>]*> eef2 5e21 	vmlsdavax.s16	r4, q1, q0
[^>]*> eef2 4e03 	vmlsdav.s16	r4, q1, q1
[^>]*> eef2 4e23 	vmlsdava.s16	r4, q1, q1
[^>]*> eef2 5e03 	vmlsdavx.s16	r4, q1, q1
[^>]*> eef2 5e23 	vmlsdavax.s16	r4, q1, q1
[^>]*> eef2 4e05 	vmlsdav.s16	r4, q1, q2
[^>]*> eef2 4e25 	vmlsdava.s16	r4, q1, q2
[^>]*> eef2 5e05 	vmlsdavx.s16	r4, q1, q2
[^>]*> eef2 5e25 	vmlsdavax.s16	r4, q1, q2
[^>]*> eef2 4e09 	vmlsdav.s16	r4, q1, q4
[^>]*> eef2 4e29 	vmlsdava.s16	r4, q1, q4
[^>]*> eef2 5e09 	vmlsdavx.s16	r4, q1, q4
[^>]*> eef2 5e29 	vmlsdavax.s16	r4, q1, q4
[^>]*> eef2 4e0f 	vmlsdav.s16	r4, q1, q7
[^>]*> eef2 4e2f 	vmlsdava.s16	r4, q1, q7
[^>]*> eef2 5e0f 	vmlsdavx.s16	r4, q1, q7
[^>]*> eef2 5e2f 	vmlsdavax.s16	r4, q1, q7
[^>]*> eef4 4e01 	vmlsdav.s16	r4, q2, q0
[^>]*> eef4 4e21 	vmlsdava.s16	r4, q2, q0
[^>]*> eef4 5e01 	vmlsdavx.s16	r4, q2, q0
[^>]*> eef4 5e21 	vmlsdavax.s16	r4, q2, q0
[^>]*> eef4 4e03 	vmlsdav.s16	r4, q2, q1
[^>]*> eef4 4e23 	vmlsdava.s16	r4, q2, q1
[^>]*> eef4 5e03 	vmlsdavx.s16	r4, q2, q1
[^>]*> eef4 5e23 	vmlsdavax.s16	r4, q2, q1
[^>]*> eef4 4e05 	vmlsdav.s16	r4, q2, q2
[^>]*> eef4 4e25 	vmlsdava.s16	r4, q2, q2
[^>]*> eef4 5e05 	vmlsdavx.s16	r4, q2, q2
[^>]*> eef4 5e25 	vmlsdavax.s16	r4, q2, q2
[^>]*> eef4 4e09 	vmlsdav.s16	r4, q2, q4
[^>]*> eef4 4e29 	vmlsdava.s16	r4, q2, q4
[^>]*> eef4 5e09 	vmlsdavx.s16	r4, q2, q4
[^>]*> eef4 5e29 	vmlsdavax.s16	r4, q2, q4
[^>]*> eef4 4e0f 	vmlsdav.s16	r4, q2, q7
[^>]*> eef4 4e2f 	vmlsdava.s16	r4, q2, q7
[^>]*> eef4 5e0f 	vmlsdavx.s16	r4, q2, q7
[^>]*> eef4 5e2f 	vmlsdavax.s16	r4, q2, q7
[^>]*> eef8 4e01 	vmlsdav.s16	r4, q4, q0
[^>]*> eef8 4e21 	vmlsdava.s16	r4, q4, q0
[^>]*> eef8 5e01 	vmlsdavx.s16	r4, q4, q0
[^>]*> eef8 5e21 	vmlsdavax.s16	r4, q4, q0
[^>]*> eef8 4e03 	vmlsdav.s16	r4, q4, q1
[^>]*> eef8 4e23 	vmlsdava.s16	r4, q4, q1
[^>]*> eef8 5e03 	vmlsdavx.s16	r4, q4, q1
[^>]*> eef8 5e23 	vmlsdavax.s16	r4, q4, q1
[^>]*> eef8 4e05 	vmlsdav.s16	r4, q4, q2
[^>]*> eef8 4e25 	vmlsdava.s16	r4, q4, q2
[^>]*> eef8 5e05 	vmlsdavx.s16	r4, q4, q2
[^>]*> eef8 5e25 	vmlsdavax.s16	r4, q4, q2
[^>]*> eef8 4e09 	vmlsdav.s16	r4, q4, q4
[^>]*> eef8 4e29 	vmlsdava.s16	r4, q4, q4
[^>]*> eef8 5e09 	vmlsdavx.s16	r4, q4, q4
[^>]*> eef8 5e29 	vmlsdavax.s16	r4, q4, q4
[^>]*> eef8 4e0f 	vmlsdav.s16	r4, q4, q7
[^>]*> eef8 4e2f 	vmlsdava.s16	r4, q4, q7
[^>]*> eef8 5e0f 	vmlsdavx.s16	r4, q4, q7
[^>]*> eef8 5e2f 	vmlsdavax.s16	r4, q4, q7
[^>]*> eefe 4e01 	vmlsdav.s16	r4, q7, q0
[^>]*> eefe 4e21 	vmlsdava.s16	r4, q7, q0
[^>]*> eefe 5e01 	vmlsdavx.s16	r4, q7, q0
[^>]*> eefe 5e21 	vmlsdavax.s16	r4, q7, q0
[^>]*> eefe 4e03 	vmlsdav.s16	r4, q7, q1
[^>]*> eefe 4e23 	vmlsdava.s16	r4, q7, q1
[^>]*> eefe 5e03 	vmlsdavx.s16	r4, q7, q1
[^>]*> eefe 5e23 	vmlsdavax.s16	r4, q7, q1
[^>]*> eefe 4e05 	vmlsdav.s16	r4, q7, q2
[^>]*> eefe 4e25 	vmlsdava.s16	r4, q7, q2
[^>]*> eefe 5e05 	vmlsdavx.s16	r4, q7, q2
[^>]*> eefe 5e25 	vmlsdavax.s16	r4, q7, q2
[^>]*> eefe 4e09 	vmlsdav.s16	r4, q7, q4
[^>]*> eefe 4e29 	vmlsdava.s16	r4, q7, q4
[^>]*> eefe 5e09 	vmlsdavx.s16	r4, q7, q4
[^>]*> eefe 5e29 	vmlsdavax.s16	r4, q7, q4
[^>]*> eefe 4e0f 	vmlsdav.s16	r4, q7, q7
[^>]*> eefe 4e2f 	vmlsdava.s16	r4, q7, q7
[^>]*> eefe 5e0f 	vmlsdavx.s16	r4, q7, q7
[^>]*> eefe 5e2f 	vmlsdavax.s16	r4, q7, q7
[^>]*> eef0 8e01 	vmlsdav.s16	r8, q0, q0
[^>]*> eef0 8e21 	vmlsdava.s16	r8, q0, q0
[^>]*> eef0 9e01 	vmlsdavx.s16	r8, q0, q0
[^>]*> eef0 9e21 	vmlsdavax.s16	r8, q0, q0
[^>]*> eef0 8e03 	vmlsdav.s16	r8, q0, q1
[^>]*> eef0 8e23 	vmlsdava.s16	r8, q0, q1
[^>]*> eef0 9e03 	vmlsdavx.s16	r8, q0, q1
[^>]*> eef0 9e23 	vmlsdavax.s16	r8, q0, q1
[^>]*> eef0 8e05 	vmlsdav.s16	r8, q0, q2
[^>]*> eef0 8e25 	vmlsdava.s16	r8, q0, q2
[^>]*> eef0 9e05 	vmlsdavx.s16	r8, q0, q2
[^>]*> eef0 9e25 	vmlsdavax.s16	r8, q0, q2
[^>]*> eef0 8e09 	vmlsdav.s16	r8, q0, q4
[^>]*> eef0 8e29 	vmlsdava.s16	r8, q0, q4
[^>]*> eef0 9e09 	vmlsdavx.s16	r8, q0, q4
[^>]*> eef0 9e29 	vmlsdavax.s16	r8, q0, q4
[^>]*> eef0 8e0f 	vmlsdav.s16	r8, q0, q7
[^>]*> eef0 8e2f 	vmlsdava.s16	r8, q0, q7
[^>]*> eef0 9e0f 	vmlsdavx.s16	r8, q0, q7
[^>]*> eef0 9e2f 	vmlsdavax.s16	r8, q0, q7
[^>]*> eef2 8e01 	vmlsdav.s16	r8, q1, q0
[^>]*> eef2 8e21 	vmlsdava.s16	r8, q1, q0
[^>]*> eef2 9e01 	vmlsdavx.s16	r8, q1, q0
[^>]*> eef2 9e21 	vmlsdavax.s16	r8, q1, q0
[^>]*> eef2 8e03 	vmlsdav.s16	r8, q1, q1
[^>]*> eef2 8e23 	vmlsdava.s16	r8, q1, q1
[^>]*> eef2 9e03 	vmlsdavx.s16	r8, q1, q1
[^>]*> eef2 9e23 	vmlsdavax.s16	r8, q1, q1
[^>]*> eef2 8e05 	vmlsdav.s16	r8, q1, q2
[^>]*> eef2 8e25 	vmlsdava.s16	r8, q1, q2
[^>]*> eef2 9e05 	vmlsdavx.s16	r8, q1, q2
[^>]*> eef2 9e25 	vmlsdavax.s16	r8, q1, q2
[^>]*> eef2 8e09 	vmlsdav.s16	r8, q1, q4
[^>]*> eef2 8e29 	vmlsdava.s16	r8, q1, q4
[^>]*> eef2 9e09 	vmlsdavx.s16	r8, q1, q4
[^>]*> eef2 9e29 	vmlsdavax.s16	r8, q1, q4
[^>]*> eef2 8e0f 	vmlsdav.s16	r8, q1, q7
[^>]*> eef2 8e2f 	vmlsdava.s16	r8, q1, q7
[^>]*> eef2 9e0f 	vmlsdavx.s16	r8, q1, q7
[^>]*> eef2 9e2f 	vmlsdavax.s16	r8, q1, q7
[^>]*> eef4 8e01 	vmlsdav.s16	r8, q2, q0
[^>]*> eef4 8e21 	vmlsdava.s16	r8, q2, q0
[^>]*> eef4 9e01 	vmlsdavx.s16	r8, q2, q0
[^>]*> eef4 9e21 	vmlsdavax.s16	r8, q2, q0
[^>]*> eef4 8e03 	vmlsdav.s16	r8, q2, q1
[^>]*> eef4 8e23 	vmlsdava.s16	r8, q2, q1
[^>]*> eef4 9e03 	vmlsdavx.s16	r8, q2, q1
[^>]*> eef4 9e23 	vmlsdavax.s16	r8, q2, q1
[^>]*> eef4 8e05 	vmlsdav.s16	r8, q2, q2
[^>]*> eef4 8e25 	vmlsdava.s16	r8, q2, q2
[^>]*> eef4 9e05 	vmlsdavx.s16	r8, q2, q2
[^>]*> eef4 9e25 	vmlsdavax.s16	r8, q2, q2
[^>]*> eef4 8e09 	vmlsdav.s16	r8, q2, q4
[^>]*> eef4 8e29 	vmlsdava.s16	r8, q2, q4
[^>]*> eef4 9e09 	vmlsdavx.s16	r8, q2, q4
[^>]*> eef4 9e29 	vmlsdavax.s16	r8, q2, q4
[^>]*> eef4 8e0f 	vmlsdav.s16	r8, q2, q7
[^>]*> eef4 8e2f 	vmlsdava.s16	r8, q2, q7
[^>]*> eef4 9e0f 	vmlsdavx.s16	r8, q2, q7
[^>]*> eef4 9e2f 	vmlsdavax.s16	r8, q2, q7
[^>]*> eef8 8e01 	vmlsdav.s16	r8, q4, q0
[^>]*> eef8 8e21 	vmlsdava.s16	r8, q4, q0
[^>]*> eef8 9e01 	vmlsdavx.s16	r8, q4, q0
[^>]*> eef8 9e21 	vmlsdavax.s16	r8, q4, q0
[^>]*> eef8 8e03 	vmlsdav.s16	r8, q4, q1
[^>]*> eef8 8e23 	vmlsdava.s16	r8, q4, q1
[^>]*> eef8 9e03 	vmlsdavx.s16	r8, q4, q1
[^>]*> eef8 9e23 	vmlsdavax.s16	r8, q4, q1
[^>]*> eef8 8e05 	vmlsdav.s16	r8, q4, q2
[^>]*> eef8 8e25 	vmlsdava.s16	r8, q4, q2
[^>]*> eef8 9e05 	vmlsdavx.s16	r8, q4, q2
[^>]*> eef8 9e25 	vmlsdavax.s16	r8, q4, q2
[^>]*> eef8 8e09 	vmlsdav.s16	r8, q4, q4
[^>]*> eef8 8e29 	vmlsdava.s16	r8, q4, q4
[^>]*> eef8 9e09 	vmlsdavx.s16	r8, q4, q4
[^>]*> eef8 9e29 	vmlsdavax.s16	r8, q4, q4
[^>]*> eef8 8e0f 	vmlsdav.s16	r8, q4, q7
[^>]*> eef8 8e2f 	vmlsdava.s16	r8, q4, q7
[^>]*> eef8 9e0f 	vmlsdavx.s16	r8, q4, q7
[^>]*> eef8 9e2f 	vmlsdavax.s16	r8, q4, q7
[^>]*> eefe 8e01 	vmlsdav.s16	r8, q7, q0
[^>]*> eefe 8e21 	vmlsdava.s16	r8, q7, q0
[^>]*> eefe 9e01 	vmlsdavx.s16	r8, q7, q0
[^>]*> eefe 9e21 	vmlsdavax.s16	r8, q7, q0
[^>]*> eefe 8e03 	vmlsdav.s16	r8, q7, q1
[^>]*> eefe 8e23 	vmlsdava.s16	r8, q7, q1
[^>]*> eefe 9e03 	vmlsdavx.s16	r8, q7, q1
[^>]*> eefe 9e23 	vmlsdavax.s16	r8, q7, q1
[^>]*> eefe 8e05 	vmlsdav.s16	r8, q7, q2
[^>]*> eefe 8e25 	vmlsdava.s16	r8, q7, q2
[^>]*> eefe 9e05 	vmlsdavx.s16	r8, q7, q2
[^>]*> eefe 9e25 	vmlsdavax.s16	r8, q7, q2
[^>]*> eefe 8e09 	vmlsdav.s16	r8, q7, q4
[^>]*> eefe 8e29 	vmlsdava.s16	r8, q7, q4
[^>]*> eefe 9e09 	vmlsdavx.s16	r8, q7, q4
[^>]*> eefe 9e29 	vmlsdavax.s16	r8, q7, q4
[^>]*> eefe 8e0f 	vmlsdav.s16	r8, q7, q7
[^>]*> eefe 8e2f 	vmlsdava.s16	r8, q7, q7
[^>]*> eefe 9e0f 	vmlsdavx.s16	r8, q7, q7
[^>]*> eefe 9e2f 	vmlsdavax.s16	r8, q7, q7
[^>]*> eef0 ae01 	vmlsdav.s16	sl, q0, q0
[^>]*> eef0 ae21 	vmlsdava.s16	sl, q0, q0
[^>]*> eef0 be01 	vmlsdavx.s16	sl, q0, q0
[^>]*> eef0 be21 	vmlsdavax.s16	sl, q0, q0
[^>]*> eef0 ae03 	vmlsdav.s16	sl, q0, q1
[^>]*> eef0 ae23 	vmlsdava.s16	sl, q0, q1
[^>]*> eef0 be03 	vmlsdavx.s16	sl, q0, q1
[^>]*> eef0 be23 	vmlsdavax.s16	sl, q0, q1
[^>]*> eef0 ae05 	vmlsdav.s16	sl, q0, q2
[^>]*> eef0 ae25 	vmlsdava.s16	sl, q0, q2
[^>]*> eef0 be05 	vmlsdavx.s16	sl, q0, q2
[^>]*> eef0 be25 	vmlsdavax.s16	sl, q0, q2
[^>]*> eef0 ae09 	vmlsdav.s16	sl, q0, q4
[^>]*> eef0 ae29 	vmlsdava.s16	sl, q0, q4
[^>]*> eef0 be09 	vmlsdavx.s16	sl, q0, q4
[^>]*> eef0 be29 	vmlsdavax.s16	sl, q0, q4
[^>]*> eef0 ae0f 	vmlsdav.s16	sl, q0, q7
[^>]*> eef0 ae2f 	vmlsdava.s16	sl, q0, q7
[^>]*> eef0 be0f 	vmlsdavx.s16	sl, q0, q7
[^>]*> eef0 be2f 	vmlsdavax.s16	sl, q0, q7
[^>]*> eef2 ae01 	vmlsdav.s16	sl, q1, q0
[^>]*> eef2 ae21 	vmlsdava.s16	sl, q1, q0
[^>]*> eef2 be01 	vmlsdavx.s16	sl, q1, q0
[^>]*> eef2 be21 	vmlsdavax.s16	sl, q1, q0
[^>]*> eef2 ae03 	vmlsdav.s16	sl, q1, q1
[^>]*> eef2 ae23 	vmlsdava.s16	sl, q1, q1
[^>]*> eef2 be03 	vmlsdavx.s16	sl, q1, q1
[^>]*> eef2 be23 	vmlsdavax.s16	sl, q1, q1
[^>]*> eef2 ae05 	vmlsdav.s16	sl, q1, q2
[^>]*> eef2 ae25 	vmlsdava.s16	sl, q1, q2
[^>]*> eef2 be05 	vmlsdavx.s16	sl, q1, q2
[^>]*> eef2 be25 	vmlsdavax.s16	sl, q1, q2
[^>]*> eef2 ae09 	vmlsdav.s16	sl, q1, q4
[^>]*> eef2 ae29 	vmlsdava.s16	sl, q1, q4
[^>]*> eef2 be09 	vmlsdavx.s16	sl, q1, q4
[^>]*> eef2 be29 	vmlsdavax.s16	sl, q1, q4
[^>]*> eef2 ae0f 	vmlsdav.s16	sl, q1, q7
[^>]*> eef2 ae2f 	vmlsdava.s16	sl, q1, q7
[^>]*> eef2 be0f 	vmlsdavx.s16	sl, q1, q7
[^>]*> eef2 be2f 	vmlsdavax.s16	sl, q1, q7
[^>]*> eef4 ae01 	vmlsdav.s16	sl, q2, q0
[^>]*> eef4 ae21 	vmlsdava.s16	sl, q2, q0
[^>]*> eef4 be01 	vmlsdavx.s16	sl, q2, q0
[^>]*> eef4 be21 	vmlsdavax.s16	sl, q2, q0
[^>]*> eef4 ae03 	vmlsdav.s16	sl, q2, q1
[^>]*> eef4 ae23 	vmlsdava.s16	sl, q2, q1
[^>]*> eef4 be03 	vmlsdavx.s16	sl, q2, q1
[^>]*> eef4 be23 	vmlsdavax.s16	sl, q2, q1
[^>]*> eef4 ae05 	vmlsdav.s16	sl, q2, q2
[^>]*> eef4 ae25 	vmlsdava.s16	sl, q2, q2
[^>]*> eef4 be05 	vmlsdavx.s16	sl, q2, q2
[^>]*> eef4 be25 	vmlsdavax.s16	sl, q2, q2
[^>]*> eef4 ae09 	vmlsdav.s16	sl, q2, q4
[^>]*> eef4 ae29 	vmlsdava.s16	sl, q2, q4
[^>]*> eef4 be09 	vmlsdavx.s16	sl, q2, q4
[^>]*> eef4 be29 	vmlsdavax.s16	sl, q2, q4
[^>]*> eef4 ae0f 	vmlsdav.s16	sl, q2, q7
[^>]*> eef4 ae2f 	vmlsdava.s16	sl, q2, q7
[^>]*> eef4 be0f 	vmlsdavx.s16	sl, q2, q7
[^>]*> eef4 be2f 	vmlsdavax.s16	sl, q2, q7
[^>]*> eef8 ae01 	vmlsdav.s16	sl, q4, q0
[^>]*> eef8 ae21 	vmlsdava.s16	sl, q4, q0
[^>]*> eef8 be01 	vmlsdavx.s16	sl, q4, q0
[^>]*> eef8 be21 	vmlsdavax.s16	sl, q4, q0
[^>]*> eef8 ae03 	vmlsdav.s16	sl, q4, q1
[^>]*> eef8 ae23 	vmlsdava.s16	sl, q4, q1
[^>]*> eef8 be03 	vmlsdavx.s16	sl, q4, q1
[^>]*> eef8 be23 	vmlsdavax.s16	sl, q4, q1
[^>]*> eef8 ae05 	vmlsdav.s16	sl, q4, q2
[^>]*> eef8 ae25 	vmlsdava.s16	sl, q4, q2
[^>]*> eef8 be05 	vmlsdavx.s16	sl, q4, q2
[^>]*> eef8 be25 	vmlsdavax.s16	sl, q4, q2
[^>]*> eef8 ae09 	vmlsdav.s16	sl, q4, q4
[^>]*> eef8 ae29 	vmlsdava.s16	sl, q4, q4
[^>]*> eef8 be09 	vmlsdavx.s16	sl, q4, q4
[^>]*> eef8 be29 	vmlsdavax.s16	sl, q4, q4
[^>]*> eef8 ae0f 	vmlsdav.s16	sl, q4, q7
[^>]*> eef8 ae2f 	vmlsdava.s16	sl, q4, q7
[^>]*> eef8 be0f 	vmlsdavx.s16	sl, q4, q7
[^>]*> eef8 be2f 	vmlsdavax.s16	sl, q4, q7
[^>]*> eefe ae01 	vmlsdav.s16	sl, q7, q0
[^>]*> eefe ae21 	vmlsdava.s16	sl, q7, q0
[^>]*> eefe be01 	vmlsdavx.s16	sl, q7, q0
[^>]*> eefe be21 	vmlsdavax.s16	sl, q7, q0
[^>]*> eefe ae03 	vmlsdav.s16	sl, q7, q1
[^>]*> eefe ae23 	vmlsdava.s16	sl, q7, q1
[^>]*> eefe be03 	vmlsdavx.s16	sl, q7, q1
[^>]*> eefe be23 	vmlsdavax.s16	sl, q7, q1
[^>]*> eefe ae05 	vmlsdav.s16	sl, q7, q2
[^>]*> eefe ae25 	vmlsdava.s16	sl, q7, q2
[^>]*> eefe be05 	vmlsdavx.s16	sl, q7, q2
[^>]*> eefe be25 	vmlsdavax.s16	sl, q7, q2
[^>]*> eefe ae09 	vmlsdav.s16	sl, q7, q4
[^>]*> eefe ae29 	vmlsdava.s16	sl, q7, q4
[^>]*> eefe be09 	vmlsdavx.s16	sl, q7, q4
[^>]*> eefe be29 	vmlsdavax.s16	sl, q7, q4
[^>]*> eefe ae0f 	vmlsdav.s16	sl, q7, q7
[^>]*> eefe ae2f 	vmlsdava.s16	sl, q7, q7
[^>]*> eefe be0f 	vmlsdavx.s16	sl, q7, q7
[^>]*> eefe be2f 	vmlsdavax.s16	sl, q7, q7
[^>]*> eef0 ce01 	vmlsdav.s16	ip, q0, q0
[^>]*> eef0 ce21 	vmlsdava.s16	ip, q0, q0
[^>]*> eef0 de01 	vmlsdavx.s16	ip, q0, q0
[^>]*> eef0 de21 	vmlsdavax.s16	ip, q0, q0
[^>]*> eef0 ce03 	vmlsdav.s16	ip, q0, q1
[^>]*> eef0 ce23 	vmlsdava.s16	ip, q0, q1
[^>]*> eef0 de03 	vmlsdavx.s16	ip, q0, q1
[^>]*> eef0 de23 	vmlsdavax.s16	ip, q0, q1
[^>]*> eef0 ce05 	vmlsdav.s16	ip, q0, q2
[^>]*> eef0 ce25 	vmlsdava.s16	ip, q0, q2
[^>]*> eef0 de05 	vmlsdavx.s16	ip, q0, q2
[^>]*> eef0 de25 	vmlsdavax.s16	ip, q0, q2
[^>]*> eef0 ce09 	vmlsdav.s16	ip, q0, q4
[^>]*> eef0 ce29 	vmlsdava.s16	ip, q0, q4
[^>]*> eef0 de09 	vmlsdavx.s16	ip, q0, q4
[^>]*> eef0 de29 	vmlsdavax.s16	ip, q0, q4
[^>]*> eef0 ce0f 	vmlsdav.s16	ip, q0, q7
[^>]*> eef0 ce2f 	vmlsdava.s16	ip, q0, q7
[^>]*> eef0 de0f 	vmlsdavx.s16	ip, q0, q7
[^>]*> eef0 de2f 	vmlsdavax.s16	ip, q0, q7
[^>]*> eef2 ce01 	vmlsdav.s16	ip, q1, q0
[^>]*> eef2 ce21 	vmlsdava.s16	ip, q1, q0
[^>]*> eef2 de01 	vmlsdavx.s16	ip, q1, q0
[^>]*> eef2 de21 	vmlsdavax.s16	ip, q1, q0
[^>]*> eef2 ce03 	vmlsdav.s16	ip, q1, q1
[^>]*> eef2 ce23 	vmlsdava.s16	ip, q1, q1
[^>]*> eef2 de03 	vmlsdavx.s16	ip, q1, q1
[^>]*> eef2 de23 	vmlsdavax.s16	ip, q1, q1
[^>]*> eef2 ce05 	vmlsdav.s16	ip, q1, q2
[^>]*> eef2 ce25 	vmlsdava.s16	ip, q1, q2
[^>]*> eef2 de05 	vmlsdavx.s16	ip, q1, q2
[^>]*> eef2 de25 	vmlsdavax.s16	ip, q1, q2
[^>]*> eef2 ce09 	vmlsdav.s16	ip, q1, q4
[^>]*> eef2 ce29 	vmlsdava.s16	ip, q1, q4
[^>]*> eef2 de09 	vmlsdavx.s16	ip, q1, q4
[^>]*> eef2 de29 	vmlsdavax.s16	ip, q1, q4
[^>]*> eef2 ce0f 	vmlsdav.s16	ip, q1, q7
[^>]*> eef2 ce2f 	vmlsdava.s16	ip, q1, q7
[^>]*> eef2 de0f 	vmlsdavx.s16	ip, q1, q7
[^>]*> eef2 de2f 	vmlsdavax.s16	ip, q1, q7
[^>]*> eef4 ce01 	vmlsdav.s16	ip, q2, q0
[^>]*> eef4 ce21 	vmlsdava.s16	ip, q2, q0
[^>]*> eef4 de01 	vmlsdavx.s16	ip, q2, q0
[^>]*> eef4 de21 	vmlsdavax.s16	ip, q2, q0
[^>]*> eef4 ce03 	vmlsdav.s16	ip, q2, q1
[^>]*> eef4 ce23 	vmlsdava.s16	ip, q2, q1
[^>]*> eef4 de03 	vmlsdavx.s16	ip, q2, q1
[^>]*> eef4 de23 	vmlsdavax.s16	ip, q2, q1
[^>]*> eef4 ce05 	vmlsdav.s16	ip, q2, q2
[^>]*> eef4 ce25 	vmlsdava.s16	ip, q2, q2
[^>]*> eef4 de05 	vmlsdavx.s16	ip, q2, q2
[^>]*> eef4 de25 	vmlsdavax.s16	ip, q2, q2
[^>]*> eef4 ce09 	vmlsdav.s16	ip, q2, q4
[^>]*> eef4 ce29 	vmlsdava.s16	ip, q2, q4
[^>]*> eef4 de09 	vmlsdavx.s16	ip, q2, q4
[^>]*> eef4 de29 	vmlsdavax.s16	ip, q2, q4
[^>]*> eef4 ce0f 	vmlsdav.s16	ip, q2, q7
[^>]*> eef4 ce2f 	vmlsdava.s16	ip, q2, q7
[^>]*> eef4 de0f 	vmlsdavx.s16	ip, q2, q7
[^>]*> eef4 de2f 	vmlsdavax.s16	ip, q2, q7
[^>]*> eef8 ce01 	vmlsdav.s16	ip, q4, q0
[^>]*> eef8 ce21 	vmlsdava.s16	ip, q4, q0
[^>]*> eef8 de01 	vmlsdavx.s16	ip, q4, q0
[^>]*> eef8 de21 	vmlsdavax.s16	ip, q4, q0
[^>]*> eef8 ce03 	vmlsdav.s16	ip, q4, q1
[^>]*> eef8 ce23 	vmlsdava.s16	ip, q4, q1
[^>]*> eef8 de03 	vmlsdavx.s16	ip, q4, q1
[^>]*> eef8 de23 	vmlsdavax.s16	ip, q4, q1
[^>]*> eef8 ce05 	vmlsdav.s16	ip, q4, q2
[^>]*> eef8 ce25 	vmlsdava.s16	ip, q4, q2
[^>]*> eef8 de05 	vmlsdavx.s16	ip, q4, q2
[^>]*> eef8 de25 	vmlsdavax.s16	ip, q4, q2
[^>]*> eef8 ce09 	vmlsdav.s16	ip, q4, q4
[^>]*> eef8 ce29 	vmlsdava.s16	ip, q4, q4
[^>]*> eef8 de09 	vmlsdavx.s16	ip, q4, q4
[^>]*> eef8 de29 	vmlsdavax.s16	ip, q4, q4
[^>]*> eef8 ce0f 	vmlsdav.s16	ip, q4, q7
[^>]*> eef8 ce2f 	vmlsdava.s16	ip, q4, q7
[^>]*> eef8 de0f 	vmlsdavx.s16	ip, q4, q7
[^>]*> eef8 de2f 	vmlsdavax.s16	ip, q4, q7
[^>]*> eefe ce01 	vmlsdav.s16	ip, q7, q0
[^>]*> eefe ce21 	vmlsdava.s16	ip, q7, q0
[^>]*> eefe de01 	vmlsdavx.s16	ip, q7, q0
[^>]*> eefe de21 	vmlsdavax.s16	ip, q7, q0
[^>]*> eefe ce03 	vmlsdav.s16	ip, q7, q1
[^>]*> eefe ce23 	vmlsdava.s16	ip, q7, q1
[^>]*> eefe de03 	vmlsdavx.s16	ip, q7, q1
[^>]*> eefe de23 	vmlsdavax.s16	ip, q7, q1
[^>]*> eefe ce05 	vmlsdav.s16	ip, q7, q2
[^>]*> eefe ce25 	vmlsdava.s16	ip, q7, q2
[^>]*> eefe de05 	vmlsdavx.s16	ip, q7, q2
[^>]*> eefe de25 	vmlsdavax.s16	ip, q7, q2
[^>]*> eefe ce09 	vmlsdav.s16	ip, q7, q4
[^>]*> eefe ce29 	vmlsdava.s16	ip, q7, q4
[^>]*> eefe de09 	vmlsdavx.s16	ip, q7, q4
[^>]*> eefe de29 	vmlsdavax.s16	ip, q7, q4
[^>]*> eefe ce0f 	vmlsdav.s16	ip, q7, q7
[^>]*> eefe ce2f 	vmlsdava.s16	ip, q7, q7
[^>]*> eefe de0f 	vmlsdavx.s16	ip, q7, q7
[^>]*> eefe de2f 	vmlsdavax.s16	ip, q7, q7
[^>]*> eef0 ee01 	vmlsdav.s16	lr, q0, q0
[^>]*> eef0 ee21 	vmlsdava.s16	lr, q0, q0
[^>]*> eef0 fe01 	vmlsdavx.s16	lr, q0, q0
[^>]*> eef0 fe21 	vmlsdavax.s16	lr, q0, q0
[^>]*> eef0 ee03 	vmlsdav.s16	lr, q0, q1
[^>]*> eef0 ee23 	vmlsdava.s16	lr, q0, q1
[^>]*> eef0 fe03 	vmlsdavx.s16	lr, q0, q1
[^>]*> eef0 fe23 	vmlsdavax.s16	lr, q0, q1
[^>]*> eef0 ee05 	vmlsdav.s16	lr, q0, q2
[^>]*> eef0 ee25 	vmlsdava.s16	lr, q0, q2
[^>]*> eef0 fe05 	vmlsdavx.s16	lr, q0, q2
[^>]*> eef0 fe25 	vmlsdavax.s16	lr, q0, q2
[^>]*> eef0 ee09 	vmlsdav.s16	lr, q0, q4
[^>]*> eef0 ee29 	vmlsdava.s16	lr, q0, q4
[^>]*> eef0 fe09 	vmlsdavx.s16	lr, q0, q4
[^>]*> eef0 fe29 	vmlsdavax.s16	lr, q0, q4
[^>]*> eef0 ee0f 	vmlsdav.s16	lr, q0, q7
[^>]*> eef0 ee2f 	vmlsdava.s16	lr, q0, q7
[^>]*> eef0 fe0f 	vmlsdavx.s16	lr, q0, q7
[^>]*> eef0 fe2f 	vmlsdavax.s16	lr, q0, q7
[^>]*> eef2 ee01 	vmlsdav.s16	lr, q1, q0
[^>]*> eef2 ee21 	vmlsdava.s16	lr, q1, q0
[^>]*> eef2 fe01 	vmlsdavx.s16	lr, q1, q0
[^>]*> eef2 fe21 	vmlsdavax.s16	lr, q1, q0
[^>]*> eef2 ee03 	vmlsdav.s16	lr, q1, q1
[^>]*> eef2 ee23 	vmlsdava.s16	lr, q1, q1
[^>]*> eef2 fe03 	vmlsdavx.s16	lr, q1, q1
[^>]*> eef2 fe23 	vmlsdavax.s16	lr, q1, q1
[^>]*> eef2 ee05 	vmlsdav.s16	lr, q1, q2
[^>]*> eef2 ee25 	vmlsdava.s16	lr, q1, q2
[^>]*> eef2 fe05 	vmlsdavx.s16	lr, q1, q2
[^>]*> eef2 fe25 	vmlsdavax.s16	lr, q1, q2
[^>]*> eef2 ee09 	vmlsdav.s16	lr, q1, q4
[^>]*> eef2 ee29 	vmlsdava.s16	lr, q1, q4
[^>]*> eef2 fe09 	vmlsdavx.s16	lr, q1, q4
[^>]*> eef2 fe29 	vmlsdavax.s16	lr, q1, q4
[^>]*> eef2 ee0f 	vmlsdav.s16	lr, q1, q7
[^>]*> eef2 ee2f 	vmlsdava.s16	lr, q1, q7
[^>]*> eef2 fe0f 	vmlsdavx.s16	lr, q1, q7
[^>]*> eef2 fe2f 	vmlsdavax.s16	lr, q1, q7
[^>]*> eef4 ee01 	vmlsdav.s16	lr, q2, q0
[^>]*> eef4 ee21 	vmlsdava.s16	lr, q2, q0
[^>]*> eef4 fe01 	vmlsdavx.s16	lr, q2, q0
[^>]*> eef4 fe21 	vmlsdavax.s16	lr, q2, q0
[^>]*> eef4 ee03 	vmlsdav.s16	lr, q2, q1
[^>]*> eef4 ee23 	vmlsdava.s16	lr, q2, q1
[^>]*> eef4 fe03 	vmlsdavx.s16	lr, q2, q1
[^>]*> eef4 fe23 	vmlsdavax.s16	lr, q2, q1
[^>]*> eef4 ee05 	vmlsdav.s16	lr, q2, q2
[^>]*> eef4 ee25 	vmlsdava.s16	lr, q2, q2
[^>]*> eef4 fe05 	vmlsdavx.s16	lr, q2, q2
[^>]*> eef4 fe25 	vmlsdavax.s16	lr, q2, q2
[^>]*> eef4 ee09 	vmlsdav.s16	lr, q2, q4
[^>]*> eef4 ee29 	vmlsdava.s16	lr, q2, q4
[^>]*> eef4 fe09 	vmlsdavx.s16	lr, q2, q4
[^>]*> eef4 fe29 	vmlsdavax.s16	lr, q2, q4
[^>]*> eef4 ee0f 	vmlsdav.s16	lr, q2, q7
[^>]*> eef4 ee2f 	vmlsdava.s16	lr, q2, q7
[^>]*> eef4 fe0f 	vmlsdavx.s16	lr, q2, q7
[^>]*> eef4 fe2f 	vmlsdavax.s16	lr, q2, q7
[^>]*> eef8 ee01 	vmlsdav.s16	lr, q4, q0
[^>]*> eef8 ee21 	vmlsdava.s16	lr, q4, q0
[^>]*> eef8 fe01 	vmlsdavx.s16	lr, q4, q0
[^>]*> eef8 fe21 	vmlsdavax.s16	lr, q4, q0
[^>]*> eef8 ee03 	vmlsdav.s16	lr, q4, q1
[^>]*> eef8 ee23 	vmlsdava.s16	lr, q4, q1
[^>]*> eef8 fe03 	vmlsdavx.s16	lr, q4, q1
[^>]*> eef8 fe23 	vmlsdavax.s16	lr, q4, q1
[^>]*> eef8 ee05 	vmlsdav.s16	lr, q4, q2
[^>]*> eef8 ee25 	vmlsdava.s16	lr, q4, q2
[^>]*> eef8 fe05 	vmlsdavx.s16	lr, q4, q2
[^>]*> eef8 fe25 	vmlsdavax.s16	lr, q4, q2
[^>]*> eef8 ee09 	vmlsdav.s16	lr, q4, q4
[^>]*> eef8 ee29 	vmlsdava.s16	lr, q4, q4
[^>]*> eef8 fe09 	vmlsdavx.s16	lr, q4, q4
[^>]*> eef8 fe29 	vmlsdavax.s16	lr, q4, q4
[^>]*> eef8 ee0f 	vmlsdav.s16	lr, q4, q7
[^>]*> eef8 ee2f 	vmlsdava.s16	lr, q4, q7
[^>]*> eef8 fe0f 	vmlsdavx.s16	lr, q4, q7
[^>]*> eef8 fe2f 	vmlsdavax.s16	lr, q4, q7
[^>]*> eefe ee01 	vmlsdav.s16	lr, q7, q0
[^>]*> eefe ee21 	vmlsdava.s16	lr, q7, q0
[^>]*> eefe fe01 	vmlsdavx.s16	lr, q7, q0
[^>]*> eefe fe21 	vmlsdavax.s16	lr, q7, q0
[^>]*> eefe ee03 	vmlsdav.s16	lr, q7, q1
[^>]*> eefe ee23 	vmlsdava.s16	lr, q7, q1
[^>]*> eefe fe03 	vmlsdavx.s16	lr, q7, q1
[^>]*> eefe fe23 	vmlsdavax.s16	lr, q7, q1
[^>]*> eefe ee05 	vmlsdav.s16	lr, q7, q2
[^>]*> eefe ee25 	vmlsdava.s16	lr, q7, q2
[^>]*> eefe fe05 	vmlsdavx.s16	lr, q7, q2
[^>]*> eefe fe25 	vmlsdavax.s16	lr, q7, q2
[^>]*> eefe ee09 	vmlsdav.s16	lr, q7, q4
[^>]*> eefe ee29 	vmlsdava.s16	lr, q7, q4
[^>]*> eefe fe09 	vmlsdavx.s16	lr, q7, q4
[^>]*> eefe fe29 	vmlsdavax.s16	lr, q7, q4
[^>]*> eefe ee0f 	vmlsdav.s16	lr, q7, q7
[^>]*> eefe ee2f 	vmlsdava.s16	lr, q7, q7
[^>]*> eefe fe0f 	vmlsdavx.s16	lr, q7, q7
[^>]*> eefe fe2f 	vmlsdavax.s16	lr, q7, q7
[^>]*> eef1 0e01 	vmlsdav.s32	r0, q0, q0
[^>]*> eef1 0e21 	vmlsdava.s32	r0, q0, q0
[^>]*> eef1 1e01 	vmlsdavx.s32	r0, q0, q0
[^>]*> eef1 1e21 	vmlsdavax.s32	r0, q0, q0
[^>]*> eef1 0e03 	vmlsdav.s32	r0, q0, q1
[^>]*> eef1 0e23 	vmlsdava.s32	r0, q0, q1
[^>]*> eef1 1e03 	vmlsdavx.s32	r0, q0, q1
[^>]*> eef1 1e23 	vmlsdavax.s32	r0, q0, q1
[^>]*> eef1 0e05 	vmlsdav.s32	r0, q0, q2
[^>]*> eef1 0e25 	vmlsdava.s32	r0, q0, q2
[^>]*> eef1 1e05 	vmlsdavx.s32	r0, q0, q2
[^>]*> eef1 1e25 	vmlsdavax.s32	r0, q0, q2
[^>]*> eef1 0e09 	vmlsdav.s32	r0, q0, q4
[^>]*> eef1 0e29 	vmlsdava.s32	r0, q0, q4
[^>]*> eef1 1e09 	vmlsdavx.s32	r0, q0, q4
[^>]*> eef1 1e29 	vmlsdavax.s32	r0, q0, q4
[^>]*> eef1 0e0f 	vmlsdav.s32	r0, q0, q7
[^>]*> eef1 0e2f 	vmlsdava.s32	r0, q0, q7
[^>]*> eef1 1e0f 	vmlsdavx.s32	r0, q0, q7
[^>]*> eef1 1e2f 	vmlsdavax.s32	r0, q0, q7
[^>]*> eef3 0e01 	vmlsdav.s32	r0, q1, q0
[^>]*> eef3 0e21 	vmlsdava.s32	r0, q1, q0
[^>]*> eef3 1e01 	vmlsdavx.s32	r0, q1, q0
[^>]*> eef3 1e21 	vmlsdavax.s32	r0, q1, q0
[^>]*> eef3 0e03 	vmlsdav.s32	r0, q1, q1
[^>]*> eef3 0e23 	vmlsdava.s32	r0, q1, q1
[^>]*> eef3 1e03 	vmlsdavx.s32	r0, q1, q1
[^>]*> eef3 1e23 	vmlsdavax.s32	r0, q1, q1
[^>]*> eef3 0e05 	vmlsdav.s32	r0, q1, q2
[^>]*> eef3 0e25 	vmlsdava.s32	r0, q1, q2
[^>]*> eef3 1e05 	vmlsdavx.s32	r0, q1, q2
[^>]*> eef3 1e25 	vmlsdavax.s32	r0, q1, q2
[^>]*> eef3 0e09 	vmlsdav.s32	r0, q1, q4
[^>]*> eef3 0e29 	vmlsdava.s32	r0, q1, q4
[^>]*> eef3 1e09 	vmlsdavx.s32	r0, q1, q4
[^>]*> eef3 1e29 	vmlsdavax.s32	r0, q1, q4
[^>]*> eef3 0e0f 	vmlsdav.s32	r0, q1, q7
[^>]*> eef3 0e2f 	vmlsdava.s32	r0, q1, q7
[^>]*> eef3 1e0f 	vmlsdavx.s32	r0, q1, q7
[^>]*> eef3 1e2f 	vmlsdavax.s32	r0, q1, q7
[^>]*> eef5 0e01 	vmlsdav.s32	r0, q2, q0
[^>]*> eef5 0e21 	vmlsdava.s32	r0, q2, q0
[^>]*> eef5 1e01 	vmlsdavx.s32	r0, q2, q0
[^>]*> eef5 1e21 	vmlsdavax.s32	r0, q2, q0
[^>]*> eef5 0e03 	vmlsdav.s32	r0, q2, q1
[^>]*> eef5 0e23 	vmlsdava.s32	r0, q2, q1
[^>]*> eef5 1e03 	vmlsdavx.s32	r0, q2, q1
[^>]*> eef5 1e23 	vmlsdavax.s32	r0, q2, q1
[^>]*> eef5 0e05 	vmlsdav.s32	r0, q2, q2
[^>]*> eef5 0e25 	vmlsdava.s32	r0, q2, q2
[^>]*> eef5 1e05 	vmlsdavx.s32	r0, q2, q2
[^>]*> eef5 1e25 	vmlsdavax.s32	r0, q2, q2
[^>]*> eef5 0e09 	vmlsdav.s32	r0, q2, q4
[^>]*> eef5 0e29 	vmlsdava.s32	r0, q2, q4
[^>]*> eef5 1e09 	vmlsdavx.s32	r0, q2, q4
[^>]*> eef5 1e29 	vmlsdavax.s32	r0, q2, q4
[^>]*> eef5 0e0f 	vmlsdav.s32	r0, q2, q7
[^>]*> eef5 0e2f 	vmlsdava.s32	r0, q2, q7
[^>]*> eef5 1e0f 	vmlsdavx.s32	r0, q2, q7
[^>]*> eef5 1e2f 	vmlsdavax.s32	r0, q2, q7
[^>]*> eef9 0e01 	vmlsdav.s32	r0, q4, q0
[^>]*> eef9 0e21 	vmlsdava.s32	r0, q4, q0
[^>]*> eef9 1e01 	vmlsdavx.s32	r0, q4, q0
[^>]*> eef9 1e21 	vmlsdavax.s32	r0, q4, q0
[^>]*> eef9 0e03 	vmlsdav.s32	r0, q4, q1
[^>]*> eef9 0e23 	vmlsdava.s32	r0, q4, q1
[^>]*> eef9 1e03 	vmlsdavx.s32	r0, q4, q1
[^>]*> eef9 1e23 	vmlsdavax.s32	r0, q4, q1
[^>]*> eef9 0e05 	vmlsdav.s32	r0, q4, q2
[^>]*> eef9 0e25 	vmlsdava.s32	r0, q4, q2
[^>]*> eef9 1e05 	vmlsdavx.s32	r0, q4, q2
[^>]*> eef9 1e25 	vmlsdavax.s32	r0, q4, q2
[^>]*> eef9 0e09 	vmlsdav.s32	r0, q4, q4
[^>]*> eef9 0e29 	vmlsdava.s32	r0, q4, q4
[^>]*> eef9 1e09 	vmlsdavx.s32	r0, q4, q4
[^>]*> eef9 1e29 	vmlsdavax.s32	r0, q4, q4
[^>]*> eef9 0e0f 	vmlsdav.s32	r0, q4, q7
[^>]*> eef9 0e2f 	vmlsdava.s32	r0, q4, q7
[^>]*> eef9 1e0f 	vmlsdavx.s32	r0, q4, q7
[^>]*> eef9 1e2f 	vmlsdavax.s32	r0, q4, q7
[^>]*> eeff 0e01 	vmlsdav.s32	r0, q7, q0
[^>]*> eeff 0e21 	vmlsdava.s32	r0, q7, q0
[^>]*> eeff 1e01 	vmlsdavx.s32	r0, q7, q0
[^>]*> eeff 1e21 	vmlsdavax.s32	r0, q7, q0
[^>]*> eeff 0e03 	vmlsdav.s32	r0, q7, q1
[^>]*> eeff 0e23 	vmlsdava.s32	r0, q7, q1
[^>]*> eeff 1e03 	vmlsdavx.s32	r0, q7, q1
[^>]*> eeff 1e23 	vmlsdavax.s32	r0, q7, q1
[^>]*> eeff 0e05 	vmlsdav.s32	r0, q7, q2
[^>]*> eeff 0e25 	vmlsdava.s32	r0, q7, q2
[^>]*> eeff 1e05 	vmlsdavx.s32	r0, q7, q2
[^>]*> eeff 1e25 	vmlsdavax.s32	r0, q7, q2
[^>]*> eeff 0e09 	vmlsdav.s32	r0, q7, q4
[^>]*> eeff 0e29 	vmlsdava.s32	r0, q7, q4
[^>]*> eeff 1e09 	vmlsdavx.s32	r0, q7, q4
[^>]*> eeff 1e29 	vmlsdavax.s32	r0, q7, q4
[^>]*> eeff 0e0f 	vmlsdav.s32	r0, q7, q7
[^>]*> eeff 0e2f 	vmlsdava.s32	r0, q7, q7
[^>]*> eeff 1e0f 	vmlsdavx.s32	r0, q7, q7
[^>]*> eeff 1e2f 	vmlsdavax.s32	r0, q7, q7
[^>]*> eef1 2e01 	vmlsdav.s32	r2, q0, q0
[^>]*> eef1 2e21 	vmlsdava.s32	r2, q0, q0
[^>]*> eef1 3e01 	vmlsdavx.s32	r2, q0, q0
[^>]*> eef1 3e21 	vmlsdavax.s32	r2, q0, q0
[^>]*> eef1 2e03 	vmlsdav.s32	r2, q0, q1
[^>]*> eef1 2e23 	vmlsdava.s32	r2, q0, q1
[^>]*> eef1 3e03 	vmlsdavx.s32	r2, q0, q1
[^>]*> eef1 3e23 	vmlsdavax.s32	r2, q0, q1
[^>]*> eef1 2e05 	vmlsdav.s32	r2, q0, q2
[^>]*> eef1 2e25 	vmlsdava.s32	r2, q0, q2
[^>]*> eef1 3e05 	vmlsdavx.s32	r2, q0, q2
[^>]*> eef1 3e25 	vmlsdavax.s32	r2, q0, q2
[^>]*> eef1 2e09 	vmlsdav.s32	r2, q0, q4
[^>]*> eef1 2e29 	vmlsdava.s32	r2, q0, q4
[^>]*> eef1 3e09 	vmlsdavx.s32	r2, q0, q4
[^>]*> eef1 3e29 	vmlsdavax.s32	r2, q0, q4
[^>]*> eef1 2e0f 	vmlsdav.s32	r2, q0, q7
[^>]*> eef1 2e2f 	vmlsdava.s32	r2, q0, q7
[^>]*> eef1 3e0f 	vmlsdavx.s32	r2, q0, q7
[^>]*> eef1 3e2f 	vmlsdavax.s32	r2, q0, q7
[^>]*> eef3 2e01 	vmlsdav.s32	r2, q1, q0
[^>]*> eef3 2e21 	vmlsdava.s32	r2, q1, q0
[^>]*> eef3 3e01 	vmlsdavx.s32	r2, q1, q0
[^>]*> eef3 3e21 	vmlsdavax.s32	r2, q1, q0
[^>]*> eef3 2e03 	vmlsdav.s32	r2, q1, q1
[^>]*> eef3 2e23 	vmlsdava.s32	r2, q1, q1
[^>]*> eef3 3e03 	vmlsdavx.s32	r2, q1, q1
[^>]*> eef3 3e23 	vmlsdavax.s32	r2, q1, q1
[^>]*> eef3 2e05 	vmlsdav.s32	r2, q1, q2
[^>]*> eef3 2e25 	vmlsdava.s32	r2, q1, q2
[^>]*> eef3 3e05 	vmlsdavx.s32	r2, q1, q2
[^>]*> eef3 3e25 	vmlsdavax.s32	r2, q1, q2
[^>]*> eef3 2e09 	vmlsdav.s32	r2, q1, q4
[^>]*> eef3 2e29 	vmlsdava.s32	r2, q1, q4
[^>]*> eef3 3e09 	vmlsdavx.s32	r2, q1, q4
[^>]*> eef3 3e29 	vmlsdavax.s32	r2, q1, q4
[^>]*> eef3 2e0f 	vmlsdav.s32	r2, q1, q7
[^>]*> eef3 2e2f 	vmlsdava.s32	r2, q1, q7
[^>]*> eef3 3e0f 	vmlsdavx.s32	r2, q1, q7
[^>]*> eef3 3e2f 	vmlsdavax.s32	r2, q1, q7
[^>]*> eef5 2e01 	vmlsdav.s32	r2, q2, q0
[^>]*> eef5 2e21 	vmlsdava.s32	r2, q2, q0
[^>]*> eef5 3e01 	vmlsdavx.s32	r2, q2, q0
[^>]*> eef5 3e21 	vmlsdavax.s32	r2, q2, q0
[^>]*> eef5 2e03 	vmlsdav.s32	r2, q2, q1
[^>]*> eef5 2e23 	vmlsdava.s32	r2, q2, q1
[^>]*> eef5 3e03 	vmlsdavx.s32	r2, q2, q1
[^>]*> eef5 3e23 	vmlsdavax.s32	r2, q2, q1
[^>]*> eef5 2e05 	vmlsdav.s32	r2, q2, q2
[^>]*> eef5 2e25 	vmlsdava.s32	r2, q2, q2
[^>]*> eef5 3e05 	vmlsdavx.s32	r2, q2, q2
[^>]*> eef5 3e25 	vmlsdavax.s32	r2, q2, q2
[^>]*> eef5 2e09 	vmlsdav.s32	r2, q2, q4
[^>]*> eef5 2e29 	vmlsdava.s32	r2, q2, q4
[^>]*> eef5 3e09 	vmlsdavx.s32	r2, q2, q4
[^>]*> eef5 3e29 	vmlsdavax.s32	r2, q2, q4
[^>]*> eef5 2e0f 	vmlsdav.s32	r2, q2, q7
[^>]*> eef5 2e2f 	vmlsdava.s32	r2, q2, q7
[^>]*> eef5 3e0f 	vmlsdavx.s32	r2, q2, q7
[^>]*> eef5 3e2f 	vmlsdavax.s32	r2, q2, q7
[^>]*> eef9 2e01 	vmlsdav.s32	r2, q4, q0
[^>]*> eef9 2e21 	vmlsdava.s32	r2, q4, q0
[^>]*> eef9 3e01 	vmlsdavx.s32	r2, q4, q0
[^>]*> eef9 3e21 	vmlsdavax.s32	r2, q4, q0
[^>]*> eef9 2e03 	vmlsdav.s32	r2, q4, q1
[^>]*> eef9 2e23 	vmlsdava.s32	r2, q4, q1
[^>]*> eef9 3e03 	vmlsdavx.s32	r2, q4, q1
[^>]*> eef9 3e23 	vmlsdavax.s32	r2, q4, q1
[^>]*> eef9 2e05 	vmlsdav.s32	r2, q4, q2
[^>]*> eef9 2e25 	vmlsdava.s32	r2, q4, q2
[^>]*> eef9 3e05 	vmlsdavx.s32	r2, q4, q2
[^>]*> eef9 3e25 	vmlsdavax.s32	r2, q4, q2
[^>]*> eef9 2e09 	vmlsdav.s32	r2, q4, q4
[^>]*> eef9 2e29 	vmlsdava.s32	r2, q4, q4
[^>]*> eef9 3e09 	vmlsdavx.s32	r2, q4, q4
[^>]*> eef9 3e29 	vmlsdavax.s32	r2, q4, q4
[^>]*> eef9 2e0f 	vmlsdav.s32	r2, q4, q7
[^>]*> eef9 2e2f 	vmlsdava.s32	r2, q4, q7
[^>]*> eef9 3e0f 	vmlsdavx.s32	r2, q4, q7
[^>]*> eef9 3e2f 	vmlsdavax.s32	r2, q4, q7
[^>]*> eeff 2e01 	vmlsdav.s32	r2, q7, q0
[^>]*> eeff 2e21 	vmlsdava.s32	r2, q7, q0
[^>]*> eeff 3e01 	vmlsdavx.s32	r2, q7, q0
[^>]*> eeff 3e21 	vmlsdavax.s32	r2, q7, q0
[^>]*> eeff 2e03 	vmlsdav.s32	r2, q7, q1
[^>]*> eeff 2e23 	vmlsdava.s32	r2, q7, q1
[^>]*> eeff 3e03 	vmlsdavx.s32	r2, q7, q1
[^>]*> eeff 3e23 	vmlsdavax.s32	r2, q7, q1
[^>]*> eeff 2e05 	vmlsdav.s32	r2, q7, q2
[^>]*> eeff 2e25 	vmlsdava.s32	r2, q7, q2
[^>]*> eeff 3e05 	vmlsdavx.s32	r2, q7, q2
[^>]*> eeff 3e25 	vmlsdavax.s32	r2, q7, q2
[^>]*> eeff 2e09 	vmlsdav.s32	r2, q7, q4
[^>]*> eeff 2e29 	vmlsdava.s32	r2, q7, q4
[^>]*> eeff 3e09 	vmlsdavx.s32	r2, q7, q4
[^>]*> eeff 3e29 	vmlsdavax.s32	r2, q7, q4
[^>]*> eeff 2e0f 	vmlsdav.s32	r2, q7, q7
[^>]*> eeff 2e2f 	vmlsdava.s32	r2, q7, q7
[^>]*> eeff 3e0f 	vmlsdavx.s32	r2, q7, q7
[^>]*> eeff 3e2f 	vmlsdavax.s32	r2, q7, q7
[^>]*> eef1 4e01 	vmlsdav.s32	r4, q0, q0
[^>]*> eef1 4e21 	vmlsdava.s32	r4, q0, q0
[^>]*> eef1 5e01 	vmlsdavx.s32	r4, q0, q0
[^>]*> eef1 5e21 	vmlsdavax.s32	r4, q0, q0
[^>]*> eef1 4e03 	vmlsdav.s32	r4, q0, q1
[^>]*> eef1 4e23 	vmlsdava.s32	r4, q0, q1
[^>]*> eef1 5e03 	vmlsdavx.s32	r4, q0, q1
[^>]*> eef1 5e23 	vmlsdavax.s32	r4, q0, q1
[^>]*> eef1 4e05 	vmlsdav.s32	r4, q0, q2
[^>]*> eef1 4e25 	vmlsdava.s32	r4, q0, q2
[^>]*> eef1 5e05 	vmlsdavx.s32	r4, q0, q2
[^>]*> eef1 5e25 	vmlsdavax.s32	r4, q0, q2
[^>]*> eef1 4e09 	vmlsdav.s32	r4, q0, q4
[^>]*> eef1 4e29 	vmlsdava.s32	r4, q0, q4
[^>]*> eef1 5e09 	vmlsdavx.s32	r4, q0, q4
[^>]*> eef1 5e29 	vmlsdavax.s32	r4, q0, q4
[^>]*> eef1 4e0f 	vmlsdav.s32	r4, q0, q7
[^>]*> eef1 4e2f 	vmlsdava.s32	r4, q0, q7
[^>]*> eef1 5e0f 	vmlsdavx.s32	r4, q0, q7
[^>]*> eef1 5e2f 	vmlsdavax.s32	r4, q0, q7
[^>]*> eef3 4e01 	vmlsdav.s32	r4, q1, q0
[^>]*> eef3 4e21 	vmlsdava.s32	r4, q1, q0
[^>]*> eef3 5e01 	vmlsdavx.s32	r4, q1, q0
[^>]*> eef3 5e21 	vmlsdavax.s32	r4, q1, q0
[^>]*> eef3 4e03 	vmlsdav.s32	r4, q1, q1
[^>]*> eef3 4e23 	vmlsdava.s32	r4, q1, q1
[^>]*> eef3 5e03 	vmlsdavx.s32	r4, q1, q1
[^>]*> eef3 5e23 	vmlsdavax.s32	r4, q1, q1
[^>]*> eef3 4e05 	vmlsdav.s32	r4, q1, q2
[^>]*> eef3 4e25 	vmlsdava.s32	r4, q1, q2
[^>]*> eef3 5e05 	vmlsdavx.s32	r4, q1, q2
[^>]*> eef3 5e25 	vmlsdavax.s32	r4, q1, q2
[^>]*> eef3 4e09 	vmlsdav.s32	r4, q1, q4
[^>]*> eef3 4e29 	vmlsdava.s32	r4, q1, q4
[^>]*> eef3 5e09 	vmlsdavx.s32	r4, q1, q4
[^>]*> eef3 5e29 	vmlsdavax.s32	r4, q1, q4
[^>]*> eef3 4e0f 	vmlsdav.s32	r4, q1, q7
[^>]*> eef3 4e2f 	vmlsdava.s32	r4, q1, q7
[^>]*> eef3 5e0f 	vmlsdavx.s32	r4, q1, q7
[^>]*> eef3 5e2f 	vmlsdavax.s32	r4, q1, q7
[^>]*> eef5 4e01 	vmlsdav.s32	r4, q2, q0
[^>]*> eef5 4e21 	vmlsdava.s32	r4, q2, q0
[^>]*> eef5 5e01 	vmlsdavx.s32	r4, q2, q0
[^>]*> eef5 5e21 	vmlsdavax.s32	r4, q2, q0
[^>]*> eef5 4e03 	vmlsdav.s32	r4, q2, q1
[^>]*> eef5 4e23 	vmlsdava.s32	r4, q2, q1
[^>]*> eef5 5e03 	vmlsdavx.s32	r4, q2, q1
[^>]*> eef5 5e23 	vmlsdavax.s32	r4, q2, q1
[^>]*> eef5 4e05 	vmlsdav.s32	r4, q2, q2
[^>]*> eef5 4e25 	vmlsdava.s32	r4, q2, q2
[^>]*> eef5 5e05 	vmlsdavx.s32	r4, q2, q2
[^>]*> eef5 5e25 	vmlsdavax.s32	r4, q2, q2
[^>]*> eef5 4e09 	vmlsdav.s32	r4, q2, q4
[^>]*> eef5 4e29 	vmlsdava.s32	r4, q2, q4
[^>]*> eef5 5e09 	vmlsdavx.s32	r4, q2, q4
[^>]*> eef5 5e29 	vmlsdavax.s32	r4, q2, q4
[^>]*> eef5 4e0f 	vmlsdav.s32	r4, q2, q7
[^>]*> eef5 4e2f 	vmlsdava.s32	r4, q2, q7
[^>]*> eef5 5e0f 	vmlsdavx.s32	r4, q2, q7
[^>]*> eef5 5e2f 	vmlsdavax.s32	r4, q2, q7
[^>]*> eef9 4e01 	vmlsdav.s32	r4, q4, q0
[^>]*> eef9 4e21 	vmlsdava.s32	r4, q4, q0
[^>]*> eef9 5e01 	vmlsdavx.s32	r4, q4, q0
[^>]*> eef9 5e21 	vmlsdavax.s32	r4, q4, q0
[^>]*> eef9 4e03 	vmlsdav.s32	r4, q4, q1
[^>]*> eef9 4e23 	vmlsdava.s32	r4, q4, q1
[^>]*> eef9 5e03 	vmlsdavx.s32	r4, q4, q1
[^>]*> eef9 5e23 	vmlsdavax.s32	r4, q4, q1
[^>]*> eef9 4e05 	vmlsdav.s32	r4, q4, q2
[^>]*> eef9 4e25 	vmlsdava.s32	r4, q4, q2
[^>]*> eef9 5e05 	vmlsdavx.s32	r4, q4, q2
[^>]*> eef9 5e25 	vmlsdavax.s32	r4, q4, q2
[^>]*> eef9 4e09 	vmlsdav.s32	r4, q4, q4
[^>]*> eef9 4e29 	vmlsdava.s32	r4, q4, q4
[^>]*> eef9 5e09 	vmlsdavx.s32	r4, q4, q4
[^>]*> eef9 5e29 	vmlsdavax.s32	r4, q4, q4
[^>]*> eef9 4e0f 	vmlsdav.s32	r4, q4, q7
[^>]*> eef9 4e2f 	vmlsdava.s32	r4, q4, q7
[^>]*> eef9 5e0f 	vmlsdavx.s32	r4, q4, q7
[^>]*> eef9 5e2f 	vmlsdavax.s32	r4, q4, q7
[^>]*> eeff 4e01 	vmlsdav.s32	r4, q7, q0
[^>]*> eeff 4e21 	vmlsdava.s32	r4, q7, q0
[^>]*> eeff 5e01 	vmlsdavx.s32	r4, q7, q0
[^>]*> eeff 5e21 	vmlsdavax.s32	r4, q7, q0
[^>]*> eeff 4e03 	vmlsdav.s32	r4, q7, q1
[^>]*> eeff 4e23 	vmlsdava.s32	r4, q7, q1
[^>]*> eeff 5e03 	vmlsdavx.s32	r4, q7, q1
[^>]*> eeff 5e23 	vmlsdavax.s32	r4, q7, q1
[^>]*> eeff 4e05 	vmlsdav.s32	r4, q7, q2
[^>]*> eeff 4e25 	vmlsdava.s32	r4, q7, q2
[^>]*> eeff 5e05 	vmlsdavx.s32	r4, q7, q2
[^>]*> eeff 5e25 	vmlsdavax.s32	r4, q7, q2
[^>]*> eeff 4e09 	vmlsdav.s32	r4, q7, q4
[^>]*> eeff 4e29 	vmlsdava.s32	r4, q7, q4
[^>]*> eeff 5e09 	vmlsdavx.s32	r4, q7, q4
[^>]*> eeff 5e29 	vmlsdavax.s32	r4, q7, q4
[^>]*> eeff 4e0f 	vmlsdav.s32	r4, q7, q7
[^>]*> eeff 4e2f 	vmlsdava.s32	r4, q7, q7
[^>]*> eeff 5e0f 	vmlsdavx.s32	r4, q7, q7
[^>]*> eeff 5e2f 	vmlsdavax.s32	r4, q7, q7
[^>]*> eef1 8e01 	vmlsdav.s32	r8, q0, q0
[^>]*> eef1 8e21 	vmlsdava.s32	r8, q0, q0
[^>]*> eef1 9e01 	vmlsdavx.s32	r8, q0, q0
[^>]*> eef1 9e21 	vmlsdavax.s32	r8, q0, q0
[^>]*> eef1 8e03 	vmlsdav.s32	r8, q0, q1
[^>]*> eef1 8e23 	vmlsdava.s32	r8, q0, q1
[^>]*> eef1 9e03 	vmlsdavx.s32	r8, q0, q1
[^>]*> eef1 9e23 	vmlsdavax.s32	r8, q0, q1
[^>]*> eef1 8e05 	vmlsdav.s32	r8, q0, q2
[^>]*> eef1 8e25 	vmlsdava.s32	r8, q0, q2
[^>]*> eef1 9e05 	vmlsdavx.s32	r8, q0, q2
[^>]*> eef1 9e25 	vmlsdavax.s32	r8, q0, q2
[^>]*> eef1 8e09 	vmlsdav.s32	r8, q0, q4
[^>]*> eef1 8e29 	vmlsdava.s32	r8, q0, q4
[^>]*> eef1 9e09 	vmlsdavx.s32	r8, q0, q4
[^>]*> eef1 9e29 	vmlsdavax.s32	r8, q0, q4
[^>]*> eef1 8e0f 	vmlsdav.s32	r8, q0, q7
[^>]*> eef1 8e2f 	vmlsdava.s32	r8, q0, q7
[^>]*> eef1 9e0f 	vmlsdavx.s32	r8, q0, q7
[^>]*> eef1 9e2f 	vmlsdavax.s32	r8, q0, q7
[^>]*> eef3 8e01 	vmlsdav.s32	r8, q1, q0
[^>]*> eef3 8e21 	vmlsdava.s32	r8, q1, q0
[^>]*> eef3 9e01 	vmlsdavx.s32	r8, q1, q0
[^>]*> eef3 9e21 	vmlsdavax.s32	r8, q1, q0
[^>]*> eef3 8e03 	vmlsdav.s32	r8, q1, q1
[^>]*> eef3 8e23 	vmlsdava.s32	r8, q1, q1
[^>]*> eef3 9e03 	vmlsdavx.s32	r8, q1, q1
[^>]*> eef3 9e23 	vmlsdavax.s32	r8, q1, q1
[^>]*> eef3 8e05 	vmlsdav.s32	r8, q1, q2
[^>]*> eef3 8e25 	vmlsdava.s32	r8, q1, q2
[^>]*> eef3 9e05 	vmlsdavx.s32	r8, q1, q2
[^>]*> eef3 9e25 	vmlsdavax.s32	r8, q1, q2
[^>]*> eef3 8e09 	vmlsdav.s32	r8, q1, q4
[^>]*> eef3 8e29 	vmlsdava.s32	r8, q1, q4
[^>]*> eef3 9e09 	vmlsdavx.s32	r8, q1, q4
[^>]*> eef3 9e29 	vmlsdavax.s32	r8, q1, q4
[^>]*> eef3 8e0f 	vmlsdav.s32	r8, q1, q7
[^>]*> eef3 8e2f 	vmlsdava.s32	r8, q1, q7
[^>]*> eef3 9e0f 	vmlsdavx.s32	r8, q1, q7
[^>]*> eef3 9e2f 	vmlsdavax.s32	r8, q1, q7
[^>]*> eef5 8e01 	vmlsdav.s32	r8, q2, q0
[^>]*> eef5 8e21 	vmlsdava.s32	r8, q2, q0
[^>]*> eef5 9e01 	vmlsdavx.s32	r8, q2, q0
[^>]*> eef5 9e21 	vmlsdavax.s32	r8, q2, q0
[^>]*> eef5 8e03 	vmlsdav.s32	r8, q2, q1
[^>]*> eef5 8e23 	vmlsdava.s32	r8, q2, q1
[^>]*> eef5 9e03 	vmlsdavx.s32	r8, q2, q1
[^>]*> eef5 9e23 	vmlsdavax.s32	r8, q2, q1
[^>]*> eef5 8e05 	vmlsdav.s32	r8, q2, q2
[^>]*> eef5 8e25 	vmlsdava.s32	r8, q2, q2
[^>]*> eef5 9e05 	vmlsdavx.s32	r8, q2, q2
[^>]*> eef5 9e25 	vmlsdavax.s32	r8, q2, q2
[^>]*> eef5 8e09 	vmlsdav.s32	r8, q2, q4
[^>]*> eef5 8e29 	vmlsdava.s32	r8, q2, q4
[^>]*> eef5 9e09 	vmlsdavx.s32	r8, q2, q4
[^>]*> eef5 9e29 	vmlsdavax.s32	r8, q2, q4
[^>]*> eef5 8e0f 	vmlsdav.s32	r8, q2, q7
[^>]*> eef5 8e2f 	vmlsdava.s32	r8, q2, q7
[^>]*> eef5 9e0f 	vmlsdavx.s32	r8, q2, q7
[^>]*> eef5 9e2f 	vmlsdavax.s32	r8, q2, q7
[^>]*> eef9 8e01 	vmlsdav.s32	r8, q4, q0
[^>]*> eef9 8e21 	vmlsdava.s32	r8, q4, q0
[^>]*> eef9 9e01 	vmlsdavx.s32	r8, q4, q0
[^>]*> eef9 9e21 	vmlsdavax.s32	r8, q4, q0
[^>]*> eef9 8e03 	vmlsdav.s32	r8, q4, q1
[^>]*> eef9 8e23 	vmlsdava.s32	r8, q4, q1
[^>]*> eef9 9e03 	vmlsdavx.s32	r8, q4, q1
[^>]*> eef9 9e23 	vmlsdavax.s32	r8, q4, q1
[^>]*> eef9 8e05 	vmlsdav.s32	r8, q4, q2
[^>]*> eef9 8e25 	vmlsdava.s32	r8, q4, q2
[^>]*> eef9 9e05 	vmlsdavx.s32	r8, q4, q2
[^>]*> eef9 9e25 	vmlsdavax.s32	r8, q4, q2
[^>]*> eef9 8e09 	vmlsdav.s32	r8, q4, q4
[^>]*> eef9 8e29 	vmlsdava.s32	r8, q4, q4
[^>]*> eef9 9e09 	vmlsdavx.s32	r8, q4, q4
[^>]*> eef9 9e29 	vmlsdavax.s32	r8, q4, q4
[^>]*> eef9 8e0f 	vmlsdav.s32	r8, q4, q7
[^>]*> eef9 8e2f 	vmlsdava.s32	r8, q4, q7
[^>]*> eef9 9e0f 	vmlsdavx.s32	r8, q4, q7
[^>]*> eef9 9e2f 	vmlsdavax.s32	r8, q4, q7
[^>]*> eeff 8e01 	vmlsdav.s32	r8, q7, q0
[^>]*> eeff 8e21 	vmlsdava.s32	r8, q7, q0
[^>]*> eeff 9e01 	vmlsdavx.s32	r8, q7, q0
[^>]*> eeff 9e21 	vmlsdavax.s32	r8, q7, q0
[^>]*> eeff 8e03 	vmlsdav.s32	r8, q7, q1
[^>]*> eeff 8e23 	vmlsdava.s32	r8, q7, q1
[^>]*> eeff 9e03 	vmlsdavx.s32	r8, q7, q1
[^>]*> eeff 9e23 	vmlsdavax.s32	r8, q7, q1
[^>]*> eeff 8e05 	vmlsdav.s32	r8, q7, q2
[^>]*> eeff 8e25 	vmlsdava.s32	r8, q7, q2
[^>]*> eeff 9e05 	vmlsdavx.s32	r8, q7, q2
[^>]*> eeff 9e25 	vmlsdavax.s32	r8, q7, q2
[^>]*> eeff 8e09 	vmlsdav.s32	r8, q7, q4
[^>]*> eeff 8e29 	vmlsdava.s32	r8, q7, q4
[^>]*> eeff 9e09 	vmlsdavx.s32	r8, q7, q4
[^>]*> eeff 9e29 	vmlsdavax.s32	r8, q7, q4
[^>]*> eeff 8e0f 	vmlsdav.s32	r8, q7, q7
[^>]*> eeff 8e2f 	vmlsdava.s32	r8, q7, q7
[^>]*> eeff 9e0f 	vmlsdavx.s32	r8, q7, q7
[^>]*> eeff 9e2f 	vmlsdavax.s32	r8, q7, q7
[^>]*> eef1 ae01 	vmlsdav.s32	sl, q0, q0
[^>]*> eef1 ae21 	vmlsdava.s32	sl, q0, q0
[^>]*> eef1 be01 	vmlsdavx.s32	sl, q0, q0
[^>]*> eef1 be21 	vmlsdavax.s32	sl, q0, q0
[^>]*> eef1 ae03 	vmlsdav.s32	sl, q0, q1
[^>]*> eef1 ae23 	vmlsdava.s32	sl, q0, q1
[^>]*> eef1 be03 	vmlsdavx.s32	sl, q0, q1
[^>]*> eef1 be23 	vmlsdavax.s32	sl, q0, q1
[^>]*> eef1 ae05 	vmlsdav.s32	sl, q0, q2
[^>]*> eef1 ae25 	vmlsdava.s32	sl, q0, q2
[^>]*> eef1 be05 	vmlsdavx.s32	sl, q0, q2
[^>]*> eef1 be25 	vmlsdavax.s32	sl, q0, q2
[^>]*> eef1 ae09 	vmlsdav.s32	sl, q0, q4
[^>]*> eef1 ae29 	vmlsdava.s32	sl, q0, q4
[^>]*> eef1 be09 	vmlsdavx.s32	sl, q0, q4
[^>]*> eef1 be29 	vmlsdavax.s32	sl, q0, q4
[^>]*> eef1 ae0f 	vmlsdav.s32	sl, q0, q7
[^>]*> eef1 ae2f 	vmlsdava.s32	sl, q0, q7
[^>]*> eef1 be0f 	vmlsdavx.s32	sl, q0, q7
[^>]*> eef1 be2f 	vmlsdavax.s32	sl, q0, q7
[^>]*> eef3 ae01 	vmlsdav.s32	sl, q1, q0
[^>]*> eef3 ae21 	vmlsdava.s32	sl, q1, q0
[^>]*> eef3 be01 	vmlsdavx.s32	sl, q1, q0
[^>]*> eef3 be21 	vmlsdavax.s32	sl, q1, q0
[^>]*> eef3 ae03 	vmlsdav.s32	sl, q1, q1
[^>]*> eef3 ae23 	vmlsdava.s32	sl, q1, q1
[^>]*> eef3 be03 	vmlsdavx.s32	sl, q1, q1
[^>]*> eef3 be23 	vmlsdavax.s32	sl, q1, q1
[^>]*> eef3 ae05 	vmlsdav.s32	sl, q1, q2
[^>]*> eef3 ae25 	vmlsdava.s32	sl, q1, q2
[^>]*> eef3 be05 	vmlsdavx.s32	sl, q1, q2
[^>]*> eef3 be25 	vmlsdavax.s32	sl, q1, q2
[^>]*> eef3 ae09 	vmlsdav.s32	sl, q1, q4
[^>]*> eef3 ae29 	vmlsdava.s32	sl, q1, q4
[^>]*> eef3 be09 	vmlsdavx.s32	sl, q1, q4
[^>]*> eef3 be29 	vmlsdavax.s32	sl, q1, q4
[^>]*> eef3 ae0f 	vmlsdav.s32	sl, q1, q7
[^>]*> eef3 ae2f 	vmlsdava.s32	sl, q1, q7
[^>]*> eef3 be0f 	vmlsdavx.s32	sl, q1, q7
[^>]*> eef3 be2f 	vmlsdavax.s32	sl, q1, q7
[^>]*> eef5 ae01 	vmlsdav.s32	sl, q2, q0
[^>]*> eef5 ae21 	vmlsdava.s32	sl, q2, q0
[^>]*> eef5 be01 	vmlsdavx.s32	sl, q2, q0
[^>]*> eef5 be21 	vmlsdavax.s32	sl, q2, q0
[^>]*> eef5 ae03 	vmlsdav.s32	sl, q2, q1
[^>]*> eef5 ae23 	vmlsdava.s32	sl, q2, q1
[^>]*> eef5 be03 	vmlsdavx.s32	sl, q2, q1
[^>]*> eef5 be23 	vmlsdavax.s32	sl, q2, q1
[^>]*> eef5 ae05 	vmlsdav.s32	sl, q2, q2
[^>]*> eef5 ae25 	vmlsdava.s32	sl, q2, q2
[^>]*> eef5 be05 	vmlsdavx.s32	sl, q2, q2
[^>]*> eef5 be25 	vmlsdavax.s32	sl, q2, q2
[^>]*> eef5 ae09 	vmlsdav.s32	sl, q2, q4
[^>]*> eef5 ae29 	vmlsdava.s32	sl, q2, q4
[^>]*> eef5 be09 	vmlsdavx.s32	sl, q2, q4
[^>]*> eef5 be29 	vmlsdavax.s32	sl, q2, q4
[^>]*> eef5 ae0f 	vmlsdav.s32	sl, q2, q7
[^>]*> eef5 ae2f 	vmlsdava.s32	sl, q2, q7
[^>]*> eef5 be0f 	vmlsdavx.s32	sl, q2, q7
[^>]*> eef5 be2f 	vmlsdavax.s32	sl, q2, q7
[^>]*> eef9 ae01 	vmlsdav.s32	sl, q4, q0
[^>]*> eef9 ae21 	vmlsdava.s32	sl, q4, q0
[^>]*> eef9 be01 	vmlsdavx.s32	sl, q4, q0
[^>]*> eef9 be21 	vmlsdavax.s32	sl, q4, q0
[^>]*> eef9 ae03 	vmlsdav.s32	sl, q4, q1
[^>]*> eef9 ae23 	vmlsdava.s32	sl, q4, q1
[^>]*> eef9 be03 	vmlsdavx.s32	sl, q4, q1
[^>]*> eef9 be23 	vmlsdavax.s32	sl, q4, q1
[^>]*> eef9 ae05 	vmlsdav.s32	sl, q4, q2
[^>]*> eef9 ae25 	vmlsdava.s32	sl, q4, q2
[^>]*> eef9 be05 	vmlsdavx.s32	sl, q4, q2
[^>]*> eef9 be25 	vmlsdavax.s32	sl, q4, q2
[^>]*> eef9 ae09 	vmlsdav.s32	sl, q4, q4
[^>]*> eef9 ae29 	vmlsdava.s32	sl, q4, q4
[^>]*> eef9 be09 	vmlsdavx.s32	sl, q4, q4
[^>]*> eef9 be29 	vmlsdavax.s32	sl, q4, q4
[^>]*> eef9 ae0f 	vmlsdav.s32	sl, q4, q7
[^>]*> eef9 ae2f 	vmlsdava.s32	sl, q4, q7
[^>]*> eef9 be0f 	vmlsdavx.s32	sl, q4, q7
[^>]*> eef9 be2f 	vmlsdavax.s32	sl, q4, q7
[^>]*> eeff ae01 	vmlsdav.s32	sl, q7, q0
[^>]*> eeff ae21 	vmlsdava.s32	sl, q7, q0
[^>]*> eeff be01 	vmlsdavx.s32	sl, q7, q0
[^>]*> eeff be21 	vmlsdavax.s32	sl, q7, q0
[^>]*> eeff ae03 	vmlsdav.s32	sl, q7, q1
[^>]*> eeff ae23 	vmlsdava.s32	sl, q7, q1
[^>]*> eeff be03 	vmlsdavx.s32	sl, q7, q1
[^>]*> eeff be23 	vmlsdavax.s32	sl, q7, q1
[^>]*> eeff ae05 	vmlsdav.s32	sl, q7, q2
[^>]*> eeff ae25 	vmlsdava.s32	sl, q7, q2
[^>]*> eeff be05 	vmlsdavx.s32	sl, q7, q2
[^>]*> eeff be25 	vmlsdavax.s32	sl, q7, q2
[^>]*> eeff ae09 	vmlsdav.s32	sl, q7, q4
[^>]*> eeff ae29 	vmlsdava.s32	sl, q7, q4
[^>]*> eeff be09 	vmlsdavx.s32	sl, q7, q4
[^>]*> eeff be29 	vmlsdavax.s32	sl, q7, q4
[^>]*> eeff ae0f 	vmlsdav.s32	sl, q7, q7
[^>]*> eeff ae2f 	vmlsdava.s32	sl, q7, q7
[^>]*> eeff be0f 	vmlsdavx.s32	sl, q7, q7
[^>]*> eeff be2f 	vmlsdavax.s32	sl, q7, q7
[^>]*> eef1 ce01 	vmlsdav.s32	ip, q0, q0
[^>]*> eef1 ce21 	vmlsdava.s32	ip, q0, q0
[^>]*> eef1 de01 	vmlsdavx.s32	ip, q0, q0
[^>]*> eef1 de21 	vmlsdavax.s32	ip, q0, q0
[^>]*> eef1 ce03 	vmlsdav.s32	ip, q0, q1
[^>]*> eef1 ce23 	vmlsdava.s32	ip, q0, q1
[^>]*> eef1 de03 	vmlsdavx.s32	ip, q0, q1
[^>]*> eef1 de23 	vmlsdavax.s32	ip, q0, q1
[^>]*> eef1 ce05 	vmlsdav.s32	ip, q0, q2
[^>]*> eef1 ce25 	vmlsdava.s32	ip, q0, q2
[^>]*> eef1 de05 	vmlsdavx.s32	ip, q0, q2
[^>]*> eef1 de25 	vmlsdavax.s32	ip, q0, q2
[^>]*> eef1 ce09 	vmlsdav.s32	ip, q0, q4
[^>]*> eef1 ce29 	vmlsdava.s32	ip, q0, q4
[^>]*> eef1 de09 	vmlsdavx.s32	ip, q0, q4
[^>]*> eef1 de29 	vmlsdavax.s32	ip, q0, q4
[^>]*> eef1 ce0f 	vmlsdav.s32	ip, q0, q7
[^>]*> eef1 ce2f 	vmlsdava.s32	ip, q0, q7
[^>]*> eef1 de0f 	vmlsdavx.s32	ip, q0, q7
[^>]*> eef1 de2f 	vmlsdavax.s32	ip, q0, q7
[^>]*> eef3 ce01 	vmlsdav.s32	ip, q1, q0
[^>]*> eef3 ce21 	vmlsdava.s32	ip, q1, q0
[^>]*> eef3 de01 	vmlsdavx.s32	ip, q1, q0
[^>]*> eef3 de21 	vmlsdavax.s32	ip, q1, q0
[^>]*> eef3 ce03 	vmlsdav.s32	ip, q1, q1
[^>]*> eef3 ce23 	vmlsdava.s32	ip, q1, q1
[^>]*> eef3 de03 	vmlsdavx.s32	ip, q1, q1
[^>]*> eef3 de23 	vmlsdavax.s32	ip, q1, q1
[^>]*> eef3 ce05 	vmlsdav.s32	ip, q1, q2
[^>]*> eef3 ce25 	vmlsdava.s32	ip, q1, q2
[^>]*> eef3 de05 	vmlsdavx.s32	ip, q1, q2
[^>]*> eef3 de25 	vmlsdavax.s32	ip, q1, q2
[^>]*> eef3 ce09 	vmlsdav.s32	ip, q1, q4
[^>]*> eef3 ce29 	vmlsdava.s32	ip, q1, q4
[^>]*> eef3 de09 	vmlsdavx.s32	ip, q1, q4
[^>]*> eef3 de29 	vmlsdavax.s32	ip, q1, q4
[^>]*> eef3 ce0f 	vmlsdav.s32	ip, q1, q7
[^>]*> eef3 ce2f 	vmlsdava.s32	ip, q1, q7
[^>]*> eef3 de0f 	vmlsdavx.s32	ip, q1, q7
[^>]*> eef3 de2f 	vmlsdavax.s32	ip, q1, q7
[^>]*> eef5 ce01 	vmlsdav.s32	ip, q2, q0
[^>]*> eef5 ce21 	vmlsdava.s32	ip, q2, q0
[^>]*> eef5 de01 	vmlsdavx.s32	ip, q2, q0
[^>]*> eef5 de21 	vmlsdavax.s32	ip, q2, q0
[^>]*> eef5 ce03 	vmlsdav.s32	ip, q2, q1
[^>]*> eef5 ce23 	vmlsdava.s32	ip, q2, q1
[^>]*> eef5 de03 	vmlsdavx.s32	ip, q2, q1
[^>]*> eef5 de23 	vmlsdavax.s32	ip, q2, q1
[^>]*> eef5 ce05 	vmlsdav.s32	ip, q2, q2
[^>]*> eef5 ce25 	vmlsdava.s32	ip, q2, q2
[^>]*> eef5 de05 	vmlsdavx.s32	ip, q2, q2
[^>]*> eef5 de25 	vmlsdavax.s32	ip, q2, q2
[^>]*> eef5 ce09 	vmlsdav.s32	ip, q2, q4
[^>]*> eef5 ce29 	vmlsdava.s32	ip, q2, q4
[^>]*> eef5 de09 	vmlsdavx.s32	ip, q2, q4
[^>]*> eef5 de29 	vmlsdavax.s32	ip, q2, q4
[^>]*> eef5 ce0f 	vmlsdav.s32	ip, q2, q7
[^>]*> eef5 ce2f 	vmlsdava.s32	ip, q2, q7
[^>]*> eef5 de0f 	vmlsdavx.s32	ip, q2, q7
[^>]*> eef5 de2f 	vmlsdavax.s32	ip, q2, q7
[^>]*> eef9 ce01 	vmlsdav.s32	ip, q4, q0
[^>]*> eef9 ce21 	vmlsdava.s32	ip, q4, q0
[^>]*> eef9 de01 	vmlsdavx.s32	ip, q4, q0
[^>]*> eef9 de21 	vmlsdavax.s32	ip, q4, q0
[^>]*> eef9 ce03 	vmlsdav.s32	ip, q4, q1
[^>]*> eef9 ce23 	vmlsdava.s32	ip, q4, q1
[^>]*> eef9 de03 	vmlsdavx.s32	ip, q4, q1
[^>]*> eef9 de23 	vmlsdavax.s32	ip, q4, q1
[^>]*> eef9 ce05 	vmlsdav.s32	ip, q4, q2
[^>]*> eef9 ce25 	vmlsdava.s32	ip, q4, q2
[^>]*> eef9 de05 	vmlsdavx.s32	ip, q4, q2
[^>]*> eef9 de25 	vmlsdavax.s32	ip, q4, q2
[^>]*> eef9 ce09 	vmlsdav.s32	ip, q4, q4
[^>]*> eef9 ce29 	vmlsdava.s32	ip, q4, q4
[^>]*> eef9 de09 	vmlsdavx.s32	ip, q4, q4
[^>]*> eef9 de29 	vmlsdavax.s32	ip, q4, q4
[^>]*> eef9 ce0f 	vmlsdav.s32	ip, q4, q7
[^>]*> eef9 ce2f 	vmlsdava.s32	ip, q4, q7
[^>]*> eef9 de0f 	vmlsdavx.s32	ip, q4, q7
[^>]*> eef9 de2f 	vmlsdavax.s32	ip, q4, q7
[^>]*> eeff ce01 	vmlsdav.s32	ip, q7, q0
[^>]*> eeff ce21 	vmlsdava.s32	ip, q7, q0
[^>]*> eeff de01 	vmlsdavx.s32	ip, q7, q0
[^>]*> eeff de21 	vmlsdavax.s32	ip, q7, q0
[^>]*> eeff ce03 	vmlsdav.s32	ip, q7, q1
[^>]*> eeff ce23 	vmlsdava.s32	ip, q7, q1
[^>]*> eeff de03 	vmlsdavx.s32	ip, q7, q1
[^>]*> eeff de23 	vmlsdavax.s32	ip, q7, q1
[^>]*> eeff ce05 	vmlsdav.s32	ip, q7, q2
[^>]*> eeff ce25 	vmlsdava.s32	ip, q7, q2
[^>]*> eeff de05 	vmlsdavx.s32	ip, q7, q2
[^>]*> eeff de25 	vmlsdavax.s32	ip, q7, q2
[^>]*> eeff ce09 	vmlsdav.s32	ip, q7, q4
[^>]*> eeff ce29 	vmlsdava.s32	ip, q7, q4
[^>]*> eeff de09 	vmlsdavx.s32	ip, q7, q4
[^>]*> eeff de29 	vmlsdavax.s32	ip, q7, q4
[^>]*> eeff ce0f 	vmlsdav.s32	ip, q7, q7
[^>]*> eeff ce2f 	vmlsdava.s32	ip, q7, q7
[^>]*> eeff de0f 	vmlsdavx.s32	ip, q7, q7
[^>]*> eeff de2f 	vmlsdavax.s32	ip, q7, q7
[^>]*> eef1 ee01 	vmlsdav.s32	lr, q0, q0
[^>]*> eef1 ee21 	vmlsdava.s32	lr, q0, q0
[^>]*> eef1 fe01 	vmlsdavx.s32	lr, q0, q0
[^>]*> eef1 fe21 	vmlsdavax.s32	lr, q0, q0
[^>]*> eef1 ee03 	vmlsdav.s32	lr, q0, q1
[^>]*> eef1 ee23 	vmlsdava.s32	lr, q0, q1
[^>]*> eef1 fe03 	vmlsdavx.s32	lr, q0, q1
[^>]*> eef1 fe23 	vmlsdavax.s32	lr, q0, q1
[^>]*> eef1 ee05 	vmlsdav.s32	lr, q0, q2
[^>]*> eef1 ee25 	vmlsdava.s32	lr, q0, q2
[^>]*> eef1 fe05 	vmlsdavx.s32	lr, q0, q2
[^>]*> eef1 fe25 	vmlsdavax.s32	lr, q0, q2
[^>]*> eef1 ee09 	vmlsdav.s32	lr, q0, q4
[^>]*> eef1 ee29 	vmlsdava.s32	lr, q0, q4
[^>]*> eef1 fe09 	vmlsdavx.s32	lr, q0, q4
[^>]*> eef1 fe29 	vmlsdavax.s32	lr, q0, q4
[^>]*> eef1 ee0f 	vmlsdav.s32	lr, q0, q7
[^>]*> eef1 ee2f 	vmlsdava.s32	lr, q0, q7
[^>]*> eef1 fe0f 	vmlsdavx.s32	lr, q0, q7
[^>]*> eef1 fe2f 	vmlsdavax.s32	lr, q0, q7
[^>]*> eef3 ee01 	vmlsdav.s32	lr, q1, q0
[^>]*> eef3 ee21 	vmlsdava.s32	lr, q1, q0
[^>]*> eef3 fe01 	vmlsdavx.s32	lr, q1, q0
[^>]*> eef3 fe21 	vmlsdavax.s32	lr, q1, q0
[^>]*> eef3 ee03 	vmlsdav.s32	lr, q1, q1
[^>]*> eef3 ee23 	vmlsdava.s32	lr, q1, q1
[^>]*> eef3 fe03 	vmlsdavx.s32	lr, q1, q1
[^>]*> eef3 fe23 	vmlsdavax.s32	lr, q1, q1
[^>]*> eef3 ee05 	vmlsdav.s32	lr, q1, q2
[^>]*> eef3 ee25 	vmlsdava.s32	lr, q1, q2
[^>]*> eef3 fe05 	vmlsdavx.s32	lr, q1, q2
[^>]*> eef3 fe25 	vmlsdavax.s32	lr, q1, q2
[^>]*> eef3 ee09 	vmlsdav.s32	lr, q1, q4
[^>]*> eef3 ee29 	vmlsdava.s32	lr, q1, q4
[^>]*> eef3 fe09 	vmlsdavx.s32	lr, q1, q4
[^>]*> eef3 fe29 	vmlsdavax.s32	lr, q1, q4
[^>]*> eef3 ee0f 	vmlsdav.s32	lr, q1, q7
[^>]*> eef3 ee2f 	vmlsdava.s32	lr, q1, q7
[^>]*> eef3 fe0f 	vmlsdavx.s32	lr, q1, q7
[^>]*> eef3 fe2f 	vmlsdavax.s32	lr, q1, q7
[^>]*> eef5 ee01 	vmlsdav.s32	lr, q2, q0
[^>]*> eef5 ee21 	vmlsdava.s32	lr, q2, q0
[^>]*> eef5 fe01 	vmlsdavx.s32	lr, q2, q0
[^>]*> eef5 fe21 	vmlsdavax.s32	lr, q2, q0
[^>]*> eef5 ee03 	vmlsdav.s32	lr, q2, q1
[^>]*> eef5 ee23 	vmlsdava.s32	lr, q2, q1
[^>]*> eef5 fe03 	vmlsdavx.s32	lr, q2, q1
[^>]*> eef5 fe23 	vmlsdavax.s32	lr, q2, q1
[^>]*> eef5 ee05 	vmlsdav.s32	lr, q2, q2
[^>]*> eef5 ee25 	vmlsdava.s32	lr, q2, q2
[^>]*> eef5 fe05 	vmlsdavx.s32	lr, q2, q2
[^>]*> eef5 fe25 	vmlsdavax.s32	lr, q2, q2
[^>]*> eef5 ee09 	vmlsdav.s32	lr, q2, q4
[^>]*> eef5 ee29 	vmlsdava.s32	lr, q2, q4
[^>]*> eef5 fe09 	vmlsdavx.s32	lr, q2, q4
[^>]*> eef5 fe29 	vmlsdavax.s32	lr, q2, q4
[^>]*> eef5 ee0f 	vmlsdav.s32	lr, q2, q7
[^>]*> eef5 ee2f 	vmlsdava.s32	lr, q2, q7
[^>]*> eef5 fe0f 	vmlsdavx.s32	lr, q2, q7
[^>]*> eef5 fe2f 	vmlsdavax.s32	lr, q2, q7
[^>]*> eef9 ee01 	vmlsdav.s32	lr, q4, q0
[^>]*> eef9 ee21 	vmlsdava.s32	lr, q4, q0
[^>]*> eef9 fe01 	vmlsdavx.s32	lr, q4, q0
[^>]*> eef9 fe21 	vmlsdavax.s32	lr, q4, q0
[^>]*> eef9 ee03 	vmlsdav.s32	lr, q4, q1
[^>]*> eef9 ee23 	vmlsdava.s32	lr, q4, q1
[^>]*> eef9 fe03 	vmlsdavx.s32	lr, q4, q1
[^>]*> eef9 fe23 	vmlsdavax.s32	lr, q4, q1
[^>]*> eef9 ee05 	vmlsdav.s32	lr, q4, q2
[^>]*> eef9 ee25 	vmlsdava.s32	lr, q4, q2
[^>]*> eef9 fe05 	vmlsdavx.s32	lr, q4, q2
[^>]*> eef9 fe25 	vmlsdavax.s32	lr, q4, q2
[^>]*> eef9 ee09 	vmlsdav.s32	lr, q4, q4
[^>]*> eef9 ee29 	vmlsdava.s32	lr, q4, q4
[^>]*> eef9 fe09 	vmlsdavx.s32	lr, q4, q4
[^>]*> eef9 fe29 	vmlsdavax.s32	lr, q4, q4
[^>]*> eef9 ee0f 	vmlsdav.s32	lr, q4, q7
[^>]*> eef9 ee2f 	vmlsdava.s32	lr, q4, q7
[^>]*> eef9 fe0f 	vmlsdavx.s32	lr, q4, q7
[^>]*> eef9 fe2f 	vmlsdavax.s32	lr, q4, q7
[^>]*> eeff ee01 	vmlsdav.s32	lr, q7, q0
[^>]*> eeff ee21 	vmlsdava.s32	lr, q7, q0
[^>]*> eeff fe01 	vmlsdavx.s32	lr, q7, q0
[^>]*> eeff fe21 	vmlsdavax.s32	lr, q7, q0
[^>]*> eeff ee03 	vmlsdav.s32	lr, q7, q1
[^>]*> eeff ee23 	vmlsdava.s32	lr, q7, q1
[^>]*> eeff fe03 	vmlsdavx.s32	lr, q7, q1
[^>]*> eeff fe23 	vmlsdavax.s32	lr, q7, q1
[^>]*> eeff ee05 	vmlsdav.s32	lr, q7, q2
[^>]*> eeff ee25 	vmlsdava.s32	lr, q7, q2
[^>]*> eeff fe05 	vmlsdavx.s32	lr, q7, q2
[^>]*> eeff fe25 	vmlsdavax.s32	lr, q7, q2
[^>]*> eeff ee09 	vmlsdav.s32	lr, q7, q4
[^>]*> eeff ee29 	vmlsdava.s32	lr, q7, q4
[^>]*> eeff fe09 	vmlsdavx.s32	lr, q7, q4
[^>]*> eeff fe29 	vmlsdavax.s32	lr, q7, q4
[^>]*> eeff ee0f 	vmlsdav.s32	lr, q7, q7
[^>]*> eeff ee2f 	vmlsdava.s32	lr, q7, q7
[^>]*> eeff fe0f 	vmlsdavx.s32	lr, q7, q7
[^>]*> eeff fe2f 	vmlsdavax.s32	lr, q7, q7
[^>]*> fe71 ef4d 	vpstete
[^>]*> fef2 0e05 	vmlsdavt.s8	r0, q1, q2
[^>]*> eef8 ae0d 	vmlsdave.s16	sl, q4, q6
[^>]*> eefb de09 	vmlsdavxt.s32	ip, q5, q4
[^>]*> fef0 3e0b 	vmlsdavxe.s8	r2, q0, q5
[^>]*> fe71 ef4d 	vpstete
[^>]*> fef2 0e25 	vmlsdavat.s8	r0, q1, q2
[^>]*> eef8 ae2d 	vmlsdavae.s16	sl, q4, q6
[^>]*> eefb de29 	vmlsdavaxt.s32	ip, q5, q4
[^>]*> fef0 3e2b 	vmlsdavaxe.s8	r2, q0, q5
